[Python-checkins] bpo-38086: Sync importlib.metadata with importlib_metadata 0.21. (GH-15840)

Brett Cannon webhook-mailer at python.org
Tue Sep 10 09:53:36 EDT 2019


https://github.com/python/cpython/commit/17499d82702432955d8e442a1871ff276ca64bc5
commit: 17499d82702432955d8e442a1871ff276ca64bc5
branch: master
author: Jason R. Coombs <jaraco at jaraco.com>
committer: Brett Cannon <54418+brettcannon at users.noreply.github.com>
date: 2019-09-10T14:53:31+01:00
summary:

bpo-38086: Sync importlib.metadata with importlib_metadata 0.21. (GH-15840)

https://gitlab.com/python-devs/importlib_metadata/-/tags/0.21

files:
A Misc/NEWS.d/next/Library/2019-09-10-11-42-59.bpo-38086.w5TlG-.rst
M Doc/library/importlib.metadata.rst
M Doc/tools/susp-ignored.csv
M Lib/importlib/_bootstrap_external.py
M Lib/importlib/metadata.py
M Lib/test/test_importlib/test_main.py
M Lib/test/test_importlib/test_metadata_api.py
M Python/importlib_external.h

diff --git a/Doc/library/importlib.metadata.rst b/Doc/library/importlib.metadata.rst
index 23c8cdeb21c2..4a4a8f7dfa0f 100644
--- a/Doc/library/importlib.metadata.rst
+++ b/Doc/library/importlib.metadata.rst
@@ -172,10 +172,10 @@ Distribution requirements
 -------------------------
 
 To get the full set of requirements for a distribution, use the ``requires()``
-function.  Note that this returns an iterator::
+function::
 
-    >>> list(requires('wheel'))  # doctest: +SKIP
-    ["pytest (>=3.0.0) ; extra == 'test'"]
+    >>> requires('wheel')  # doctest: +SKIP
+    ["pytest (>=3.0.0) ; extra == 'test'", "pytest-cov ; extra == 'test'"]
 
 
 Distributions
@@ -224,23 +224,25 @@ The abstract class :py:class:`importlib.abc.MetaPathFinder` defines the
 interface expected of finders by Python's import system.
 ``importlib.metadata`` extends this protocol by looking for an optional
 ``find_distributions`` callable on the finders from
-``sys.meta_path``.  If the finder has this method, it must return
-an iterator over instances of the ``Distribution`` abstract class. This
-method must have the signature::
+``sys.meta_path`` and presents this extended interface as the
+``DistributionFinder`` abstract base class, which defines this abstract
+method::
 
-    def find_distributions(name=None, path=None):
+    @abc.abstractmethod
+    def find_distributions(context=DistributionFinder.Context()):
         """Return an iterable of all Distribution instances capable of
-        loading the metadata for packages matching the name
-        (or all names if not supplied) along the paths in the list
-        of directories ``path`` (defaults to sys.path).
+        loading the metadata for packages for the indicated ``context``.
         """
 
+The ``DistributionFinder.Context`` object provides ``.path`` and ``.name``
+properties indicating the path to search and names to match and may
+supply other relevant context.
+
 What this means in practice is that to support finding distribution package
 metadata in locations other than the file system, you should derive from
-``Distribution`` and implement the ``load_metadata()`` method.  This takes a
-single argument which is the name of the package whose metadata is being
-found.  This instance of the ``Distribution`` base abstract class is what your
-finder's ``find_distributions()`` method should return.
+``Distribution`` and implement the ``load_metadata()`` method. Then from
+your finder, return instances of this derived ``Distribution`` in the
+``find_distributions()`` method.
 
 
 .. _`entry point API`: https://setuptools.readthedocs.io/en/latest/pkg_resources.html#entry-points
diff --git a/Doc/tools/susp-ignored.csv b/Doc/tools/susp-ignored.csv
index 43d8d6e28f2f..bc0dcb60b65b 100644
--- a/Doc/tools/susp-ignored.csv
+++ b/Doc/tools/susp-ignored.csv
@@ -352,4 +352,4 @@ whatsnew/changelog,,::,error::BytesWarning
 whatsnew/changelog,,::,default::BytesWarning
 whatsnew/changelog,,::,default::DeprecationWarning
 library/importlib.metadata,,:main,"EntryPoint(name='wheel', value='wheel.cli:main', group='console_scripts')"
-library/importlib.metadata,,`,of directories ``path`` (defaults to sys.path).
+library/importlib.metadata,,`,loading the metadata for packages for the indicated ``context``.
diff --git a/Lib/importlib/metadata.py b/Lib/importlib/metadata.py
index 3b46142231ec..e23076654fe4 100644
--- a/Lib/importlib/metadata.py
+++ b/Lib/importlib/metadata.py
@@ -19,6 +19,7 @@
 
 __all__ = [
     'Distribution',
+    'DistributionFinder',
     'PackageNotFoundError',
     'distribution',
     'distributions',
@@ -158,7 +159,7 @@ def from_name(cls, name):
             metadata cannot be found.
         """
         for resolver in cls._discover_resolvers():
-            dists = resolver(name)
+            dists = resolver(DistributionFinder.Context(name=name))
             dist = next(dists, None)
             if dist is not None:
                 return dist
@@ -166,16 +167,33 @@ def from_name(cls, name):
             raise PackageNotFoundError(name)
 
     @classmethod
-    def discover(cls):
+    def discover(cls, **kwargs):
         """Return an iterable of Distribution objects for all packages.
 
+        Pass a ``context`` or pass keyword arguments for constructing
+        a context.
+
+        :context: A ``DistributionFinder.Context`` object.
         :return: Iterable of Distribution objects for all packages.
         """
+        context = kwargs.pop('context', None)
+        if context and kwargs:
+            raise ValueError("cannot accept context and kwargs")
+        context = context or DistributionFinder.Context(**kwargs)
         return itertools.chain.from_iterable(
-            resolver()
+            resolver(context)
             for resolver in cls._discover_resolvers()
             )
 
+    @staticmethod
+    def at(path):
+        """Return a Distribution for the indicated metadata path
+
+        :param path: a string or path-like object
+        :return: a concrete Distribution instance for the path
+        """
+        return PathDistribution(pathlib.Path(path))
+
     @staticmethod
     def _discover_resolvers():
         """Search the meta_path for resolvers."""
@@ -215,7 +233,7 @@ def entry_points(self):
     def files(self):
         """Files in this distribution.
 
-        :return: Iterable of PackagePath for this distribution or None
+        :return: List of PackagePath for this distribution or None
 
         Result is `None` if the metadata file that enumerates files
         (i.e. RECORD for dist-info or SOURCES.txt for egg-info) is
@@ -231,7 +249,7 @@ def make_file(name, hash=None, size_str=None):
             result.dist = self
             return result
 
-        return file_lines and starmap(make_file, csv.reader(file_lines))
+        return file_lines and list(starmap(make_file, csv.reader(file_lines)))
 
     def _read_files_distinfo(self):
         """
@@ -251,7 +269,8 @@ def _read_files_egginfo(self):
     @property
     def requires(self):
         """Generated requirements specified for this Distribution"""
-        return self._read_dist_info_reqs() or self._read_egg_info_reqs()
+        reqs = self._read_dist_info_reqs() or self._read_egg_info_reqs()
+        return reqs and list(reqs)
 
     def _read_dist_info_reqs(self):
         return self.metadata.get_all('Requires-Dist')
@@ -312,15 +331,35 @@ class DistributionFinder(MetaPathFinder):
     A MetaPathFinder capable of discovering installed distributions.
     """
 
+    class Context:
+
+        name = None
+        """
+        Specific name for which a distribution finder should match.
+        """
+
+        def __init__(self, **kwargs):
+            vars(self).update(kwargs)
+
+        @property
+        def path(self):
+            """
+            The path that a distribution finder should search.
+            """
+            return vars(self).get('path', sys.path)
+
+        @property
+        def pattern(self):
+            return '.*' if self.name is None else re.escape(self.name)
+
     @abc.abstractmethod
-    def find_distributions(self, name=None, path=None):
+    def find_distributions(self, context=Context()):
         """
         Find distributions.
 
         Return an iterable of all Distribution instances capable of
-        loading the metadata for packages matching the ``name``
-        (or all names if not supplied) along the paths in the list
-        of directories ``path`` (defaults to sys.path).
+        loading the metadata for packages matching the ``context``,
+        a DistributionFinder.Context instance.
         """
 
 
@@ -352,12 +391,12 @@ def distribution(package):
     return Distribution.from_name(package)
 
 
-def distributions():
+def distributions(**kwargs):
     """Get all ``Distribution`` instances in the current environment.
 
     :return: An iterable of ``Distribution`` instances.
     """
-    return Distribution.discover()
+    return Distribution.discover(**kwargs)
 
 
 def metadata(package):
diff --git a/Lib/test/test_importlib/test_main.py b/Lib/test/test_importlib/test_main.py
index 3d7da819b343..4d5b1273d9d1 100644
--- a/Lib/test/test_importlib/test_main.py
+++ b/Lib/test/test_importlib/test_main.py
@@ -162,6 +162,10 @@ def test_package_discovery(self):
             for dist in dists
             )
 
+    def test_invalid_usage(self):
+        with self.assertRaises(ValueError):
+            list(distributions(context='something', name='else'))
+
 
 class DirectoryTest(fixtures.OnSysPath, fixtures.SiteDir, unittest.TestCase):
     def test_egg_info(self):
diff --git a/Lib/test/test_importlib/test_metadata_api.py b/Lib/test/test_importlib/test_metadata_api.py
index af3bab3558ef..1d7b29ae05fd 100644
--- a/Lib/test/test_importlib/test_metadata_api.py
+++ b/Lib/test/test_importlib/test_metadata_api.py
@@ -1,7 +1,6 @@
 import re
 import textwrap
 import unittest
-import itertools
 
 from collections.abc import Iterator
 
@@ -61,9 +60,7 @@ def test_metadata_for_this_package(self):
         assert 'Topic :: Software Development :: Libraries' in classifiers
 
     @staticmethod
-    def _test_files(files_iter):
-        assert isinstance(files_iter, Iterator), files_iter
-        files = list(files_iter)
+    def _test_files(files):
         root = files[0].root
         for file in files:
             assert file.root == root
@@ -99,16 +96,18 @@ def test_requires_egg_info_file(self):
         requirements = requires('egginfo-file')
         self.assertIsNone(requirements)
 
-    def test_requires(self):
+    def test_requires_egg_info(self):
         deps = requires('egginfo-pkg')
+        assert len(deps) == 2
         assert any(
             dep == 'wheel >= 1.0; python_version >= "2.7"'
             for dep in deps
             )
 
     def test_requires_dist_info(self):
-        deps = list(requires('distinfo-pkg'))
-        assert deps and all(deps)
+        deps = requires('distinfo-pkg')
+        assert len(deps) == 2
+        assert all(deps)
         assert 'wheel >= 1.0' in deps
         assert "pytest; extra == 'test'" in deps
 
@@ -143,11 +142,20 @@ def test_more_complex_deps_requires_text(self):
 
 class OffSysPathTests(fixtures.DistInfoPkgOffPath, unittest.TestCase):
     def test_find_distributions_specified_path(self):
-        dists = itertools.chain.from_iterable(
-            resolver(path=[str(self.site_dir)])
-            for resolver in Distribution._discover_resolvers()
-            )
+        dists = Distribution.discover(path=[str(self.site_dir)])
         assert any(
             dist.metadata['Name'] == 'distinfo-pkg'
             for dist in dists
             )
+
+    def test_distribution_at_pathlib(self):
+        """Demonstrate how to load metadata direct from a directory.
+        """
+        dist_info_path = self.site_dir / 'distinfo_pkg-1.0.0.dist-info'
+        dist = Distribution.at(dist_info_path)
+        assert dist.version == '1.0.0'
+
+    def test_distribution_at_str(self):
+        dist_info_path = self.site_dir / 'distinfo_pkg-1.0.0.dist-info'
+        dist = Distribution.at(str(dist_info_path))
+        assert dist.version == '1.0.0'
diff --git a/Misc/NEWS.d/next/Library/2019-09-10-11-42-59.bpo-38086.w5TlG-.rst b/Misc/NEWS.d/next/Library/2019-09-10-11-42-59.bpo-38086.w5TlG-.rst
new file mode 100644
index 000000000000..40db53c97da4
--- /dev/null
+++ b/Misc/NEWS.d/next/Library/2019-09-10-11-42-59.bpo-38086.w5TlG-.rst
@@ -0,0 +1 @@
+Update importlib.metadata with changes from `importlib_metadata 0.21 <https://gitlab.com/python-devs/importlib_metadata/blob/0.21/importlib_metadata/docs/changelog.rst>`_.
\ No newline at end of file
diff --git a/Python/importlib_external.h b/Python/importlib_external.h
index c69819676af8..b9d14d64b402 100644
--- a/Python/importlib_external.h
+++ b/Python/importlib_external.h
@@ -2235,619 +2235,618 @@ const unsigned char _Py_M__importlib_bootstrap_external[] = {
     3,0,0,0,114,3,0,0,0,114,6,0,0,0,114,205,
     0,0,0,79,5,0,0,115,8,0,0,0,0,8,12,1,
     8,1,4,1,122,22,80,97,116,104,70,105,110,100,101,114,
-    46,102,105,110,100,95,109,111,100,117,108,101,99,3,0,0,
-    0,0,0,0,0,0,0,0,0,7,0,0,0,4,0,0,
-    0,67,0,0,0,115,78,0,0,0,100,1,100,2,108,0,
-    125,3,100,1,100,3,108,1,109,2,125,4,1,0,124,2,
-    100,2,107,8,114,34,116,3,106,4,125,2,124,1,100,2,
-    107,8,114,46,100,4,110,8,124,3,160,5,124,1,161,1,
-    125,5,124,0,160,6,124,5,124,2,161,2,125,6,116,7,
-    124,4,124,6,131,2,83,0,41,5,97,37,1,0,0,10,
-    32,32,32,32,32,32,32,32,70,105,110,100,32,100,105,115,
-    116,114,105,98,117,116,105,111,110,115,46,10,10,32,32,32,
-    32,32,32,32,32,82,101,116,117,114,110,32,97,110,32,105,
-    116,101,114,97,98,108,101,32,111,102,32,97,108,108,32,68,
-    105,115,116,114,105,98,117,116,105,111,110,32,105,110,115,116,
-    97,110,99,101,115,32,99,97,112,97,98,108,101,32,111,102,
-    10,32,32,32,32,32,32,32,32,108,111,97,100,105,110,103,
-    32,116,104,101,32,109,101,116,97,100,97,116,97,32,102,111,
-    114,32,112,97,99,107,97,103,101,115,32,109,97,116,99,104,
-    105,110,103,32,116,104,101,32,96,96,110,97,109,101,96,96,
+    46,102,105,110,100,95,109,111,100,117,108,101,99,2,0,0,
+    0,0,0,0,0,0,0,0,0,5,0,0,0,4,0,0,
+    0,67,0,0,0,115,58,0,0,0,100,1,100,2,108,0,
+    109,1,125,2,109,2,125,3,1,0,124,1,100,3,107,8,
+    114,32,124,3,160,3,161,0,125,1,124,0,160,4,124,1,
+    106,5,124,1,106,6,161,2,125,4,116,7,124,2,124,4,
+    131,2,83,0,41,4,97,32,1,0,0,10,32,32,32,32,
+    32,32,32,32,70,105,110,100,32,100,105,115,116,114,105,98,
+    117,116,105,111,110,115,46,10,10,32,32,32,32,32,32,32,
+    32,82,101,116,117,114,110,32,97,110,32,105,116,101,114,97,
+    98,108,101,32,111,102,32,97,108,108,32,68,105,115,116,114,
+    105,98,117,116,105,111,110,32,105,110,115,116,97,110,99,101,
+    115,32,99,97,112,97,98,108,101,32,111,102,10,32,32,32,
+    32,32,32,32,32,108,111,97,100,105,110,103,32,116,104,101,
+    32,109,101,116,97,100,97,116,97,32,102,111,114,32,112,97,
+    99,107,97,103,101,115,32,109,97,116,99,104,105,110,103,32,
+    96,96,99,111,110,116,101,120,116,46,110,97,109,101,96,96,
     10,32,32,32,32,32,32,32,32,40,111,114,32,97,108,108,
-    32,110,97,109,101,115,32,105,102,32,110,111,116,32,115,117,
-    112,112,108,105,101,100,41,32,97,108,111,110,103,32,116,104,
-    101,32,112,97,116,104,115,32,105,110,32,116,104,101,32,108,
-    105,115,116,10,32,32,32,32,32,32,32,32,111,102,32,100,
-    105,114,101,99,116,111,114,105,101,115,32,96,96,112,97,116,
-    104,96,96,32,40,100,101,102,97,117,108,116,115,32,116,111,
-    32,115,121,115,46,112,97,116,104,41,46,10,32,32,32,32,
-    32,32,32,32,114,72,0,0,0,78,41,1,218,16,80,97,
-    116,104,68,105,115,116,114,105,98,117,116,105,111,110,122,2,
-    46,42,41,8,218,2,114,101,90,18,105,109,112,111,114,116,
-    108,105,98,46,109,101,116,97,100,97,116,97,114,58,1,0,
-    0,114,8,0,0,0,114,43,0,0,0,90,6,101,115,99,
-    97,112,101,218,13,95,115,101,97,114,99,104,95,112,97,116,
-    104,115,218,3,109,97,112,41,7,114,192,0,0,0,114,116,
-    0,0,0,114,43,0,0,0,114,59,1,0,0,114,58,1,
-    0,0,218,7,112,97,116,116,101,114,110,90,5,102,111,117,
-    110,100,114,3,0,0,0,114,3,0,0,0,114,6,0,0,
-    0,218,18,102,105,110,100,95,100,105,115,116,114,105,98,117,
-    116,105,111,110,115,92,5,0,0,115,14,0,0,0,0,10,
-    8,1,12,1,8,1,6,1,22,1,12,1,122,29,80,97,
-    116,104,70,105,110,100,101,114,46,102,105,110,100,95,100,105,
-    115,116,114,105,98,117,116,105,111,110,115,99,3,0,0,0,
-    0,0,0,0,0,0,0,0,4,0,0,0,6,0,0,0,
-    3,0,0,0,115,44,0,0,0,100,1,100,2,108,0,125,
-    3,124,3,106,1,160,2,135,0,135,1,102,2,100,3,100,
-    4,132,8,116,3,136,0,106,4,124,2,131,2,68,0,131,
-    1,161,1,83,0,41,5,122,49,70,105,110,100,32,109,101,
-    116,97,100,97,116,97,32,100,105,114,101,99,116,111,114,105,
-    101,115,32,105,110,32,112,97,116,104,115,32,104,101,117,114,
-    105,115,116,105,99,97,108,108,121,46,114,72,0,0,0,78,
-    99,1,0,0,0,0,0,0,0,0,0,0,0,2,0,0,
-    0,5,0,0,0,51,0,0,0,115,26,0,0,0,124,0,
-    93,18,125,1,136,0,160,0,124,1,136,1,161,2,86,0,
-    1,0,113,2,100,0,83,0,114,109,0,0,0,41,1,218,
-    12,95,115,101,97,114,99,104,95,112,97,116,104,41,2,114,
-    31,0,0,0,114,43,0,0,0,169,2,114,192,0,0,0,
-    114,62,1,0,0,114,3,0,0,0,114,6,0,0,0,114,
-    18,1,0,0,114,5,0,0,115,4,0,0,0,4,2,2,
-    255,122,43,80,97,116,104,70,105,110,100,101,114,46,95,115,
-    101,97,114,99,104,95,112,97,116,104,115,46,60,108,111,99,
-    97,108,115,62,46,60,103,101,110,101,120,112,114,62,41,5,
-    218,9,105,116,101,114,116,111,111,108,115,90,5,99,104,97,
-    105,110,90,13,102,114,111,109,95,105,116,101,114,97,98,108,
-    101,114,61,1,0,0,218,12,95,115,119,105,116,99,104,95,
-    112,97,116,104,41,4,114,192,0,0,0,114,62,1,0,0,
-    90,5,112,97,116,104,115,114,66,1,0,0,114,3,0,0,
-    0,114,65,1,0,0,114,6,0,0,0,114,60,1,0,0,
-    110,5,0,0,115,8,0,0,0,0,3,8,1,18,2,10,
-    254,122,24,80,97,116,104,70,105,110,100,101,114,46,95,115,
-    101,97,114,99,104,95,112,97,116,104,115,99,1,0,0,0,
-    0,0,0,0,0,0,0,0,5,0,0,0,10,0,0,0,
-    67,0,0,0,115,96,0,0,0,100,1,100,2,108,0,109,
-    1,125,1,1,0,100,1,100,0,108,2,125,2,100,1,100,
-    0,108,3,125,3,100,3,125,4,124,4,114,48,116,4,106,
-    5,160,6,124,0,161,1,114,86,124,1,116,7,131,1,143,
-    24,1,0,124,2,160,8,124,0,161,1,87,0,2,0,53,
-    0,81,0,82,0,163,0,83,0,81,0,82,0,88,0,124,
-    3,160,8,124,0,161,1,83,0,41,4,78,114,72,0,0,
-    0,41,1,218,8,115,117,112,112,114,101,115,115,70,41,9,
-    90,10,99,111,110,116,101,120,116,108,105,98,114,68,1,0,
-    0,218,7,122,105,112,102,105,108,101,218,7,112,97,116,104,
-    108,105,98,90,2,111,115,114,43,0,0,0,90,6,105,115,
-    102,105,108,101,218,9,69,120,99,101,112,116,105,111,110,90,
-    4,80,97,116,104,41,5,114,43,0,0,0,114,68,1,0,
-    0,114,69,1,0,0,114,70,1,0,0,90,13,80,89,80,
-    89,95,79,80,69,78,95,66,85,71,114,3,0,0,0,114,
-    3,0,0,0,114,6,0,0,0,114,67,1,0,0,119,5,
-    0,0,115,16,0,0,0,0,2,12,1,8,1,8,1,4,
-    1,16,1,10,1,28,1,122,23,80,97,116,104,70,105,110,
-    100,101,114,46,95,115,119,105,116,99,104,95,112,97,116,104,
-    99,3,0,0,0,0,0,0,0,0,0,0,0,6,0,0,
-    0,5,0,0,0,67,0,0,0,115,44,0,0,0,100,1,
-    100,0,108,0,125,3,100,2,125,4,124,4,106,1,124,1,
-    100,3,141,1,125,5,124,3,106,2,124,5,124,2,106,3,
+    32,110,97,109,101,115,32,105,102,32,96,96,78,111,110,101,
+    96,96,32,105,110,100,105,99,97,116,101,100,41,32,97,108,
+    111,110,103,32,116,104,101,32,112,97,116,104,115,32,105,110,
+    32,116,104,101,32,108,105,115,116,10,32,32,32,32,32,32,
+    32,32,111,102,32,100,105,114,101,99,116,111,114,105,101,115,
+    32,96,96,99,111,110,116,101,120,116,46,112,97,116,104,96,
+    96,46,10,32,32,32,32,32,32,32,32,114,72,0,0,0,
+    41,2,218,16,80,97,116,104,68,105,115,116,114,105,98,117,
+    116,105,111,110,218,18,68,105,115,116,114,105,98,117,116,105,
+    111,110,70,105,110,100,101,114,78,41,8,90,18,105,109,112,
+    111,114,116,108,105,98,46,109,101,116,97,100,97,116,97,114,
+    58,1,0,0,114,59,1,0,0,90,7,67,111,110,116,101,
+    120,116,218,13,95,115,101,97,114,99,104,95,112,97,116,104,
+    115,218,7,112,97,116,116,101,114,110,114,43,0,0,0,218,
+    3,109,97,112,41,5,114,118,0,0,0,90,7,99,111,110,
+    116,101,120,116,114,58,1,0,0,114,59,1,0,0,90,5,
+    102,111,117,110,100,114,3,0,0,0,114,3,0,0,0,114,
+    6,0,0,0,218,18,102,105,110,100,95,100,105,115,116,114,
+    105,98,117,116,105,111,110,115,92,5,0,0,115,10,0,0,
+    0,0,10,16,1,8,1,8,1,16,1,122,29,80,97,116,
+    104,70,105,110,100,101,114,46,102,105,110,100,95,100,105,115,
+    116,114,105,98,117,116,105,111,110,115,99,3,0,0,0,0,
+    0,0,0,0,0,0,0,4,0,0,0,6,0,0,0,3,
+    0,0,0,115,44,0,0,0,100,1,100,2,108,0,125,3,
+    124,3,106,1,160,2,135,0,135,1,102,2,100,3,100,4,
+    132,8,116,3,136,0,106,4,124,2,131,2,68,0,131,1,
+    161,1,83,0,41,5,122,49,70,105,110,100,32,109,101,116,
+    97,100,97,116,97,32,100,105,114,101,99,116,111,114,105,101,
+    115,32,105,110,32,112,97,116,104,115,32,104,101,117,114,105,
+    115,116,105,99,97,108,108,121,46,114,72,0,0,0,78,99,
+    1,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,
+    5,0,0,0,51,0,0,0,115,26,0,0,0,124,0,93,
+    18,125,1,136,0,160,0,124,1,136,1,161,2,86,0,1,
+    0,113,2,100,0,83,0,114,109,0,0,0,41,1,218,12,
+    95,115,101,97,114,99,104,95,112,97,116,104,41,2,114,31,
+    0,0,0,114,43,0,0,0,169,2,114,192,0,0,0,114,
+    61,1,0,0,114,3,0,0,0,114,6,0,0,0,114,18,
+    1,0,0,112,5,0,0,115,4,0,0,0,4,2,2,255,
+    122,43,80,97,116,104,70,105,110,100,101,114,46,95,115,101,
+    97,114,99,104,95,112,97,116,104,115,46,60,108,111,99,97,
+    108,115,62,46,60,103,101,110,101,120,112,114,62,41,5,218,
+    9,105,116,101,114,116,111,111,108,115,90,5,99,104,97,105,
+    110,90,13,102,114,111,109,95,105,116,101,114,97,98,108,101,
+    114,62,1,0,0,218,12,95,115,119,105,116,99,104,95,112,
+    97,116,104,41,4,114,192,0,0,0,114,61,1,0,0,90,
+    5,112,97,116,104,115,114,66,1,0,0,114,3,0,0,0,
+    114,65,1,0,0,114,6,0,0,0,114,60,1,0,0,108,
+    5,0,0,115,8,0,0,0,0,3,8,1,18,2,10,254,
+    122,24,80,97,116,104,70,105,110,100,101,114,46,95,115,101,
+    97,114,99,104,95,112,97,116,104,115,99,1,0,0,0,0,
+    0,0,0,0,0,0,0,5,0,0,0,10,0,0,0,67,
+    0,0,0,115,96,0,0,0,100,1,100,2,108,0,109,1,
+    125,1,1,0,100,1,100,0,108,2,125,2,100,1,100,0,
+    108,3,125,3,100,3,125,4,124,4,114,48,116,4,106,5,
+    160,6,124,0,161,1,114,86,124,1,116,7,131,1,143,24,
+    1,0,124,2,160,8,124,0,161,1,87,0,2,0,53,0,
+    81,0,82,0,163,0,83,0,81,0,82,0,88,0,124,3,
+    160,8,124,0,161,1,83,0,41,4,78,114,72,0,0,0,
+    41,1,218,8,115,117,112,112,114,101,115,115,70,41,9,90,
+    10,99,111,110,116,101,120,116,108,105,98,114,68,1,0,0,
+    218,7,122,105,112,102,105,108,101,218,7,112,97,116,104,108,
+    105,98,90,2,111,115,114,43,0,0,0,90,6,105,115,102,
+    105,108,101,218,9,69,120,99,101,112,116,105,111,110,90,4,
+    80,97,116,104,41,5,114,43,0,0,0,114,68,1,0,0,
+    114,69,1,0,0,114,70,1,0,0,90,13,80,89,80,89,
+    95,79,80,69,78,95,66,85,71,114,3,0,0,0,114,3,
+    0,0,0,114,6,0,0,0,114,67,1,0,0,117,5,0,
+    0,115,16,0,0,0,0,2,12,1,8,1,8,1,4,1,
+    16,1,10,1,28,1,122,23,80,97,116,104,70,105,110,100,
+    101,114,46,95,115,119,105,116,99,104,95,112,97,116,104,99,
+    3,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,
+    5,0,0,0,67,0,0,0,115,44,0,0,0,100,1,100,
+    0,108,0,125,3,100,2,125,4,124,4,106,1,124,1,100,
+    3,141,1,125,5,124,3,106,2,124,5,124,2,106,3,124,
+    3,106,4,100,4,141,3,83,0,41,5,78,114,72,0,0,
+    0,122,32,123,112,97,116,116,101,114,110,125,40,45,46,42,
+    41,63,92,46,40,100,105,115,116,124,101,103,103,41,45,105,
+    110,102,111,169,1,114,61,1,0,0,169,1,114,82,0,0,
+    0,41,5,218,2,114,101,114,61,0,0,0,90,5,109,97,
+    116,99,104,114,116,0,0,0,218,10,73,71,78,79,82,69,
+    67,65,83,69,169,6,114,192,0,0,0,218,10,110,111,114,
+    109,97,108,105,122,101,100,114,40,1,0,0,114,74,1,0,
+    0,90,8,116,101,109,112,108,97,116,101,90,8,109,97,110,
+    105,102,101,115,116,114,3,0,0,0,114,3,0,0,0,114,
+    6,0,0,0,218,13,95,109,97,116,99,104,101,115,95,105,
+    110,102,111,128,5,0,0,115,8,0,0,0,0,2,8,1,
+    4,1,12,1,122,24,80,97,116,104,70,105,110,100,101,114,
+    46,95,109,97,116,99,104,101,115,95,105,110,102,111,99,3,
+    0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,5,
+    0,0,0,67,0,0,0,115,46,0,0,0,100,1,100,0,
+    108,0,125,3,100,2,125,4,124,4,106,1,124,1,100,3,
+    141,1,125,5,124,3,106,2,124,5,116,3,124,2,131,1,
     124,3,106,4,100,4,141,3,83,0,41,5,78,114,72,0,
-    0,0,122,32,123,112,97,116,116,101,114,110,125,40,45,46,
-    42,41,63,92,46,40,100,105,115,116,124,101,103,103,41,45,
-    105,110,102,111,169,1,114,62,1,0,0,169,1,114,82,0,
-    0,0,41,5,114,59,1,0,0,114,61,0,0,0,90,5,
-    109,97,116,99,104,114,116,0,0,0,218,10,73,71,78,79,
-    82,69,67,65,83,69,169,6,114,192,0,0,0,218,10,110,
-    111,114,109,97,108,105,122,101,100,114,40,1,0,0,114,59,
-    1,0,0,90,8,116,101,109,112,108,97,116,101,90,8,109,
-    97,110,105,102,101,115,116,114,3,0,0,0,114,3,0,0,
-    0,114,6,0,0,0,218,13,95,109,97,116,99,104,101,115,
-    95,105,110,102,111,130,5,0,0,115,8,0,0,0,0,2,
-    8,1,4,1,12,1,122,24,80,97,116,104,70,105,110,100,
-    101,114,46,95,109,97,116,99,104,101,115,95,105,110,102,111,
-    99,3,0,0,0,0,0,0,0,0,0,0,0,6,0,0,
-    0,5,0,0,0,67,0,0,0,115,46,0,0,0,100,1,
-    100,0,108,0,125,3,100,2,125,4,124,4,106,1,124,1,
-    100,3,141,1,125,5,124,3,106,2,124,5,116,3,124,2,
-    131,1,124,3,106,4,100,4,141,3,83,0,41,5,78,114,
-    72,0,0,0,122,30,123,112,97,116,116,101,114,110,125,45,
-    46,42,92,46,101,103,103,91,92,92,47,93,69,71,71,45,
-    73,78,70,79,114,72,1,0,0,114,73,1,0,0,41,5,
-    114,59,1,0,0,114,61,0,0,0,90,6,115,101,97,114,
-    99,104,114,84,0,0,0,114,74,1,0,0,114,75,1,0,
-    0,114,3,0,0,0,114,3,0,0,0,114,6,0,0,0,
-    218,15,95,109,97,116,99,104,101,115,95,108,101,103,97,99,
-    121,137,5,0,0,115,8,0,0,0,0,2,8,1,4,1,
-    12,1,122,26,80,97,116,104,70,105,110,100,101,114,46,95,
-    109,97,116,99,104,101,115,95,108,101,103,97,99,121,99,3,
-    0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,4,
-    0,0,0,3,0,0,0,115,48,0,0,0,124,1,160,0,
-    161,0,115,12,100,1,83,0,124,2,160,1,100,2,100,3,
-    161,2,137,1,135,0,135,1,102,2,100,4,100,5,132,8,
-    124,1,160,2,161,0,68,0,131,1,83,0,41,6,78,114,
-    3,0,0,0,250,1,45,114,44,0,0,0,99,1,0,0,
-    0,0,0,0,0,0,0,0,0,2,0,0,0,5,0,0,
-    0,51,0,0,0,115,42,0,0,0,124,0,93,34,125,1,
-    136,0,160,0,136,1,124,1,161,2,115,30,136,0,160,1,
-    136,1,124,1,161,2,114,2,124,1,86,0,1,0,113,2,
-    100,0,83,0,114,109,0,0,0,41,2,114,77,1,0,0,
-    114,78,1,0,0,41,2,114,31,0,0,0,114,40,1,0,
-    0,169,2,114,192,0,0,0,114,76,1,0,0,114,3,0,
-    0,0,114,6,0,0,0,114,18,1,0,0,149,5,0,0,
-    115,8,0,0,0,4,0,2,1,12,1,12,254,122,42,80,
-    97,116,104,70,105,110,100,101,114,46,95,115,101,97,114,99,
-    104,95,112,97,116,104,46,60,108,111,99,97,108,115,62,46,
-    60,103,101,110,101,120,112,114,62,41,3,90,6,105,115,95,
-    100,105,114,114,66,0,0,0,90,7,105,116,101,114,100,105,
-    114,41,3,114,192,0,0,0,90,4,114,111,111,116,114,62,
-    1,0,0,114,3,0,0,0,114,80,1,0,0,114,6,0,
-    0,0,114,64,1,0,0,144,5,0,0,115,8,0,0,0,
-    0,2,8,1,4,1,12,1,122,23,80,97,116,104,70,105,
-    110,100,101,114,46,95,115,101,97,114,99,104,95,112,97,116,
-    104,41,1,78,41,2,78,78,41,1,78,41,2,78,78,41,
-    19,114,124,0,0,0,114,123,0,0,0,114,125,0,0,0,
-    114,126,0,0,0,114,206,0,0,0,114,45,1,0,0,114,
-    51,1,0,0,114,53,1,0,0,114,54,1,0,0,114,57,
-    1,0,0,114,202,0,0,0,114,205,0,0,0,114,63,1,
-    0,0,114,60,1,0,0,218,12,115,116,97,116,105,99,109,
-    101,116,104,111,100,114,67,1,0,0,114,77,1,0,0,114,
-    78,1,0,0,114,64,1,0,0,114,3,0,0,0,114,3,
-    0,0,0,114,3,0,0,0,114,6,0,0,0,114,44,1,
-    0,0,215,4,0,0,115,54,0,0,0,8,2,4,2,2,
-    1,10,9,2,1,10,12,2,1,10,21,2,1,10,14,2,
-    1,12,31,2,1,12,23,2,1,12,12,2,1,12,17,2,
-    1,10,8,2,1,10,10,2,1,10,6,2,1,10,6,2,
-    1,114,44,1,0,0,99,0,0,0,0,0,0,0,0,0,
-    0,0,0,0,0,0,0,3,0,0,0,64,0,0,0,115,
-    90,0,0,0,101,0,90,1,100,0,90,2,100,1,90,3,
-    100,2,100,3,132,0,90,4,100,4,100,5,132,0,90,5,
-    101,6,90,7,100,6,100,7,132,0,90,8,100,8,100,9,
-    132,0,90,9,100,19,100,11,100,12,132,1,90,10,100,13,
-    100,14,132,0,90,11,101,12,100,15,100,16,132,0,131,1,
-    90,13,100,17,100,18,132,0,90,14,100,10,83,0,41,20,
-    218,10,70,105,108,101,70,105,110,100,101,114,122,172,70,105,
-    108,101,45,98,97,115,101,100,32,102,105,110,100,101,114,46,
-    10,10,32,32,32,32,73,110,116,101,114,97,99,116,105,111,
-    110,115,32,119,105,116,104,32,116,104,101,32,102,105,108,101,
-    32,115,121,115,116,101,109,32,97,114,101,32,99,97,99,104,
-    101,100,32,102,111,114,32,112,101,114,102,111,114,109,97,110,
-    99,101,44,32,98,101,105,110,103,10,32,32,32,32,114,101,
-    102,114,101,115,104,101,100,32,119,104,101,110,32,116,104,101,
-    32,100,105,114,101,99,116,111,114,121,32,116,104,101,32,102,
-    105,110,100,101,114,32,105,115,32,104,97,110,100,108,105,110,
-    103,32,104,97,115,32,98,101,101,110,32,109,111,100,105,102,
-    105,101,100,46,10,10,32,32,32,32,99,2,0,0,0,0,
-    0,0,0,0,0,0,0,5,0,0,0,6,0,0,0,7,
-    0,0,0,115,84,0,0,0,103,0,125,3,124,2,68,0,
-    93,32,92,2,137,0,125,4,124,3,160,0,135,0,102,1,
-    100,1,100,2,132,8,124,4,68,0,131,1,161,1,1,0,
-    113,8,124,3,124,0,95,1,124,1,112,54,100,3,124,0,
-    95,2,100,4,124,0,95,3,116,4,131,0,124,0,95,5,
-    116,4,131,0,124,0,95,6,100,5,83,0,41,6,122,154,
-    73,110,105,116,105,97,108,105,122,101,32,119,105,116,104,32,
-    116,104,101,32,112,97,116,104,32,116,111,32,115,101,97,114,
-    99,104,32,111,110,32,97,110,100,32,97,32,118,97,114,105,
-    97,98,108,101,32,110,117,109,98,101,114,32,111,102,10,32,
-    32,32,32,32,32,32,32,50,45,116,117,112,108,101,115,32,
-    99,111,110,116,97,105,110,105,110,103,32,116,104,101,32,108,
-    111,97,100,101,114,32,97,110,100,32,116,104,101,32,102,105,
-    108,101,32,115,117,102,102,105,120,101,115,32,116,104,101,32,
-    108,111,97,100,101,114,10,32,32,32,32,32,32,32,32,114,
-    101,99,111,103,110,105,122,101,115,46,99,1,0,0,0,0,
-    0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,51,
-    0,0,0,115,22,0,0,0,124,0,93,14,125,1,124,1,
-    136,0,102,2,86,0,1,0,113,2,100,0,83,0,114,109,
-    0,0,0,114,3,0,0,0,114,15,1,0,0,169,1,114,
-    139,0,0,0,114,3,0,0,0,114,6,0,0,0,114,18,
-    1,0,0,169,5,0,0,115,4,0,0,0,4,0,2,0,
-    122,38,70,105,108,101,70,105,110,100,101,114,46,95,95,105,
-    110,105,116,95,95,46,60,108,111,99,97,108,115,62,46,60,
-    103,101,110,101,120,112,114,62,114,70,0,0,0,114,104,0,
-    0,0,78,41,7,114,166,0,0,0,218,8,95,108,111,97,
-    100,101,114,115,114,43,0,0,0,218,11,95,112,97,116,104,
-    95,109,116,105,109,101,218,3,115,101,116,218,11,95,112,97,
-    116,104,95,99,97,99,104,101,218,19,95,114,101,108,97,120,
-    101,100,95,112,97,116,104,95,99,97,99,104,101,41,5,114,
-    118,0,0,0,114,43,0,0,0,218,14,108,111,97,100,101,
-    114,95,100,101,116,97,105,108,115,90,7,108,111,97,100,101,
-    114,115,114,188,0,0,0,114,3,0,0,0,114,83,1,0,
-    0,114,6,0,0,0,114,208,0,0,0,163,5,0,0,115,
-    16,0,0,0,0,4,4,1,12,1,26,1,6,2,10,1,
-    6,1,8,1,122,19,70,105,108,101,70,105,110,100,101,114,
-    46,95,95,105,110,105,116,95,95,99,1,0,0,0,0,0,
-    0,0,0,0,0,0,1,0,0,0,2,0,0,0,67,0,
-    0,0,115,10,0,0,0,100,1,124,0,95,0,100,2,83,
-    0,41,3,122,31,73,110,118,97,108,105,100,97,116,101,32,
-    116,104,101,32,100,105,114,101,99,116,111,114,121,32,109,116,
-    105,109,101,46,114,104,0,0,0,78,41,1,114,85,1,0,
-    0,114,245,0,0,0,114,3,0,0,0,114,3,0,0,0,
-    114,6,0,0,0,114,45,1,0,0,177,5,0,0,115,2,
-    0,0,0,0,2,122,28,70,105,108,101,70,105,110,100,101,
-    114,46,105,110,118,97,108,105,100,97,116,101,95,99,97,99,
-    104,101,115,99,2,0,0,0,0,0,0,0,0,0,0,0,
-    3,0,0,0,3,0,0,0,67,0,0,0,115,42,0,0,
-    0,124,0,160,0,124,1,161,1,125,2,124,2,100,1,107,
-    8,114,26,100,1,103,0,102,2,83,0,124,2,106,1,124,
-    2,106,2,112,38,103,0,102,2,83,0,41,2,122,197,84,
-    114,121,32,116,111,32,102,105,110,100,32,97,32,108,111,97,
-    100,101,114,32,102,111,114,32,116,104,101,32,115,112,101,99,
-    105,102,105,101,100,32,109,111,100,117,108,101,44,32,111,114,
-    32,116,104,101,32,110,97,109,101,115,112,97,99,101,10,32,
-    32,32,32,32,32,32,32,112,97,99,107,97,103,101,32,112,
-    111,114,116,105,111,110,115,46,32,82,101,116,117,114,110,115,
-    32,40,108,111,97,100,101,114,44,32,108,105,115,116,45,111,
-    102,45,112,111,114,116,105,111,110,115,41,46,10,10,32,32,
-    32,32,32,32,32,32,84,104,105,115,32,109,101,116,104,111,
-    100,32,105,115,32,100,101,112,114,101,99,97,116,101,100,46,
-    32,32,85,115,101,32,102,105,110,100,95,115,112,101,99,40,
-    41,32,105,110,115,116,101,97,100,46,10,10,32,32,32,32,
-    32,32,32,32,78,41,3,114,202,0,0,0,114,139,0,0,
-    0,114,177,0,0,0,41,3,114,118,0,0,0,114,138,0,
-    0,0,114,186,0,0,0,114,3,0,0,0,114,3,0,0,
-    0,114,6,0,0,0,114,136,0,0,0,183,5,0,0,115,
-    8,0,0,0,0,7,10,1,8,1,8,1,122,22,70,105,
-    108,101,70,105,110,100,101,114,46,102,105,110,100,95,108,111,
-    97,100,101,114,99,6,0,0,0,0,0,0,0,0,0,0,
-    0,7,0,0,0,6,0,0,0,67,0,0,0,115,26,0,
-    0,0,124,1,124,2,124,3,131,2,125,6,116,0,124,2,
-    124,3,124,6,124,4,100,1,141,4,83,0,41,2,78,114,
-    176,0,0,0,41,1,114,189,0,0,0,41,7,114,118,0,
-    0,0,114,187,0,0,0,114,138,0,0,0,114,43,0,0,
-    0,90,4,115,109,115,108,114,201,0,0,0,114,139,0,0,
-    0,114,3,0,0,0,114,3,0,0,0,114,6,0,0,0,
-    114,57,1,0,0,195,5,0,0,115,8,0,0,0,0,1,
-    10,1,8,1,2,255,122,20,70,105,108,101,70,105,110,100,
-    101,114,46,95,103,101,116,95,115,112,101,99,78,99,3,0,
-    0,0,0,0,0,0,0,0,0,0,14,0,0,0,8,0,
-    0,0,67,0,0,0,115,98,1,0,0,100,1,125,3,124,
-    1,160,0,100,2,161,1,100,3,25,0,125,4,122,24,116,
-    1,124,0,106,2,112,34,116,3,160,4,161,0,131,1,106,
-    5,125,5,87,0,110,24,4,0,116,6,107,10,114,66,1,
-    0,1,0,1,0,100,4,125,5,89,0,110,2,88,0,124,
-    5,124,0,106,7,107,3,114,92,124,0,160,8,161,0,1,
-    0,124,5,124,0,95,7,116,9,131,0,114,114,124,0,106,
-    10,125,6,124,4,160,11,161,0,125,7,110,10,124,0,106,
-    12,125,6,124,4,125,7,124,7,124,6,107,6,114,218,116,
-    13,124,0,106,2,124,4,131,2,125,8,124,0,106,14,68,
-    0,93,58,92,2,125,9,125,10,100,5,124,9,23,0,125,
-    11,116,13,124,8,124,11,131,2,125,12,116,15,124,12,131,
-    1,114,150,124,0,160,16,124,10,124,1,124,12,124,8,103,
-    1,124,2,161,5,2,0,1,0,83,0,113,150,116,17,124,
-    8,131,1,125,3,124,0,106,14,68,0,93,82,92,2,125,
-    9,125,10,116,13,124,0,106,2,124,4,124,9,23,0,131,
-    2,125,12,116,18,106,19,100,6,124,12,100,3,100,7,141,
-    3,1,0,124,7,124,9,23,0,124,6,107,6,114,224,116,
-    15,124,12,131,1,114,224,124,0,160,16,124,10,124,1,124,
-    12,100,8,124,2,161,5,2,0,1,0,83,0,113,224,124,
-    3,144,1,114,94,116,18,160,19,100,9,124,8,161,2,1,
-    0,116,18,160,20,124,1,100,8,161,2,125,13,124,8,103,
-    1,124,13,95,21,124,13,83,0,100,8,83,0,41,10,122,
-    111,84,114,121,32,116,111,32,102,105,110,100,32,97,32,115,
-    112,101,99,32,102,111,114,32,116,104,101,32,115,112,101,99,
-    105,102,105,101,100,32,109,111,100,117,108,101,46,10,10,32,
-    32,32,32,32,32,32,32,82,101,116,117,114,110,115,32,116,
-    104,101,32,109,97,116,99,104,105,110,103,32,115,112,101,99,
-    44,32,111,114,32,78,111,110,101,32,105,102,32,110,111,116,
-    32,102,111,117,110,100,46,10,32,32,32,32,32,32,32,32,
-    70,114,70,0,0,0,114,27,0,0,0,114,104,0,0,0,
-    114,208,0,0,0,122,9,116,114,121,105,110,103,32,123,125,
-    41,1,90,9,118,101,114,98,111,115,105,116,121,78,122,25,
-    112,111,115,115,105,98,108,101,32,110,97,109,101,115,112,97,
-    99,101,32,102,111,114,32,123,125,41,22,114,40,0,0,0,
-    114,48,0,0,0,114,43,0,0,0,114,2,0,0,0,114,
-    54,0,0,0,114,9,1,0,0,114,49,0,0,0,114,85,
-    1,0,0,218,11,95,102,105,108,108,95,99,97,99,104,101,
-    114,7,0,0,0,114,88,1,0,0,114,105,0,0,0,114,
-    87,1,0,0,114,37,0,0,0,114,84,1,0,0,114,53,
-    0,0,0,114,57,1,0,0,114,55,0,0,0,114,133,0,
-    0,0,114,148,0,0,0,114,182,0,0,0,114,177,0,0,
-    0,41,14,114,118,0,0,0,114,138,0,0,0,114,201,0,
-    0,0,90,12,105,115,95,110,97,109,101,115,112,97,99,101,
-    90,11,116,97,105,108,95,109,111,100,117,108,101,114,168,0,
-    0,0,90,5,99,97,99,104,101,90,12,99,97,99,104,101,
-    95,109,111,100,117,108,101,90,9,98,97,115,101,95,112,97,
-    116,104,114,16,1,0,0,114,187,0,0,0,90,13,105,110,
-    105,116,95,102,105,108,101,110,97,109,101,90,9,102,117,108,
-    108,95,112,97,116,104,114,186,0,0,0,114,3,0,0,0,
-    114,3,0,0,0,114,6,0,0,0,114,202,0,0,0,200,
-    5,0,0,115,74,0,0,0,0,5,4,1,14,1,2,1,
-    24,1,14,1,10,1,10,1,8,1,6,2,6,1,6,1,
-    10,2,6,1,4,2,8,1,12,1,14,1,8,1,10,1,
-    8,1,26,4,8,2,14,1,16,1,16,1,12,1,8,1,
-    10,1,2,0,2,255,10,2,6,1,12,1,12,1,8,1,
-    4,1,122,20,70,105,108,101,70,105,110,100,101,114,46,102,
-    105,110,100,95,115,112,101,99,99,1,0,0,0,0,0,0,
-    0,0,0,0,0,9,0,0,0,10,0,0,0,67,0,0,
-    0,115,190,0,0,0,124,0,106,0,125,1,122,22,116,1,
-    160,2,124,1,112,22,116,1,160,3,161,0,161,1,125,2,
-    87,0,110,30,4,0,116,4,116,5,116,6,102,3,107,10,
-    114,58,1,0,1,0,1,0,103,0,125,2,89,0,110,2,
-    88,0,116,7,106,8,160,9,100,1,161,1,115,84,116,10,
-    124,2,131,1,124,0,95,11,110,74,116,10,131,0,125,3,
-    124,2,68,0,93,56,125,4,124,4,160,12,100,2,161,1,
-    92,3,125,5,125,6,125,7,124,6,114,136,100,3,160,13,
-    124,5,124,7,160,14,161,0,161,2,125,8,110,4,124,5,
-    125,8,124,3,160,15,124,8,161,1,1,0,113,94,124,3,
-    124,0,95,11,116,7,106,8,160,9,116,16,161,1,114,186,
-    100,4,100,5,132,0,124,2,68,0,131,1,124,0,95,17,
-    100,6,83,0,41,7,122,68,70,105,108,108,32,116,104,101,
-    32,99,97,99,104,101,32,111,102,32,112,111,116,101,110,116,
-    105,97,108,32,109,111,100,117,108,101,115,32,97,110,100,32,
-    112,97,99,107,97,103,101,115,32,102,111,114,32,116,104,105,
-    115,32,100,105,114,101,99,116,111,114,121,46,114,0,0,0,
-    0,114,70,0,0,0,114,60,0,0,0,99,1,0,0,0,
-    0,0,0,0,0,0,0,0,2,0,0,0,4,0,0,0,
-    83,0,0,0,115,20,0,0,0,104,0,124,0,93,12,125,
-    1,124,1,160,0,161,0,146,2,113,4,83,0,114,3,0,
-    0,0,41,1,114,105,0,0,0,41,2,114,31,0,0,0,
-    90,2,102,110,114,3,0,0,0,114,3,0,0,0,114,6,
-    0,0,0,218,9,60,115,101,116,99,111,109,112,62,21,6,
-    0,0,115,4,0,0,0,6,0,2,0,122,41,70,105,108,
-    101,70,105,110,100,101,114,46,95,102,105,108,108,95,99,97,
-    99,104,101,46,60,108,111,99,97,108,115,62,46,60,115,101,
-    116,99,111,109,112,62,78,41,18,114,43,0,0,0,114,2,
-    0,0,0,114,6,1,0,0,114,54,0,0,0,114,2,1,
-    0,0,218,15,80,101,114,109,105,115,115,105,111,110,69,114,
-    114,111,114,218,18,78,111,116,65,68,105,114,101,99,116,111,
-    114,121,69,114,114,111,114,114,8,0,0,0,114,9,0,0,
-    0,114,10,0,0,0,114,86,1,0,0,114,87,1,0,0,
-    114,100,0,0,0,114,61,0,0,0,114,105,0,0,0,218,
-    3,97,100,100,114,11,0,0,0,114,88,1,0,0,41,9,
-    114,118,0,0,0,114,43,0,0,0,114,7,1,0,0,90,
-    21,108,111,119,101,114,95,115,117,102,102,105,120,95,99,111,
-    110,116,101,110,116,115,114,40,1,0,0,114,116,0,0,0,
-    114,28,1,0,0,114,16,1,0,0,90,8,110,101,119,95,
-    110,97,109,101,114,3,0,0,0,114,3,0,0,0,114,6,
-    0,0,0,114,90,1,0,0,248,5,0,0,115,34,0,0,
-    0,0,2,6,1,2,1,22,1,20,3,10,3,12,1,12,
-    7,6,1,8,1,16,1,4,1,18,2,4,1,12,1,6,
-    1,12,1,122,22,70,105,108,101,70,105,110,100,101,114,46,
-    95,102,105,108,108,95,99,97,99,104,101,99,1,0,0,0,
-    0,0,0,0,0,0,0,0,3,0,0,0,3,0,0,0,
-    7,0,0,0,115,18,0,0,0,135,0,135,1,102,2,100,
-    1,100,2,132,8,125,2,124,2,83,0,41,3,97,20,1,
-    0,0,65,32,99,108,97,115,115,32,109,101,116,104,111,100,
-    32,119,104,105,99,104,32,114,101,116,117,114,110,115,32,97,
-    32,99,108,111,115,117,114,101,32,116,111,32,117,115,101,32,
-    111,110,32,115,121,115,46,112,97,116,104,95,104,111,111,107,
-    10,32,32,32,32,32,32,32,32,119,104,105,99,104,32,119,
-    105,108,108,32,114,101,116,117,114,110,32,97,110,32,105,110,
-    115,116,97,110,99,101,32,117,115,105,110,103,32,116,104,101,
-    32,115,112,101,99,105,102,105,101,100,32,108,111,97,100,101,
-    114,115,32,97,110,100,32,116,104,101,32,112,97,116,104,10,
-    32,32,32,32,32,32,32,32,99,97,108,108,101,100,32,111,
-    110,32,116,104,101,32,99,108,111,115,117,114,101,46,10,10,
-    32,32,32,32,32,32,32,32,73,102,32,116,104,101,32,112,
-    97,116,104,32,99,97,108,108,101,100,32,111,110,32,116,104,
-    101,32,99,108,111,115,117,114,101,32,105,115,32,110,111,116,
-    32,97,32,100,105,114,101,99,116,111,114,121,44,32,73,109,
-    112,111,114,116,69,114,114,111,114,32,105,115,10,32,32,32,
-    32,32,32,32,32,114,97,105,115,101,100,46,10,10,32,32,
-    32,32,32,32,32,32,99,1,0,0,0,0,0,0,0,0,
-    0,0,0,1,0,0,0,4,0,0,0,19,0,0,0,115,
-    34,0,0,0,116,0,124,0,131,1,115,20,116,1,100,1,
-    124,0,100,2,141,2,130,1,136,0,124,0,102,1,136,1,
-    158,2,142,0,83,0,41,3,122,45,80,97,116,104,32,104,
-    111,111,107,32,102,111,114,32,105,109,112,111,114,116,108,105,
-    98,46,109,97,99,104,105,110,101,114,121,46,70,105,108,101,
-    70,105,110,100,101,114,46,122,30,111,110,108,121,32,100,105,
-    114,101,99,116,111,114,105,101,115,32,97,114,101,32,115,117,
-    112,112,111,114,116,101,100,114,47,0,0,0,41,2,114,55,
-    0,0,0,114,117,0,0,0,114,47,0,0,0,169,2,114,
-    192,0,0,0,114,89,1,0,0,114,3,0,0,0,114,6,
-    0,0,0,218,24,112,97,116,104,95,104,111,111,107,95,102,
-    111,114,95,70,105,108,101,70,105,110,100,101,114,33,6,0,
-    0,115,6,0,0,0,0,2,8,1,12,1,122,54,70,105,
-    108,101,70,105,110,100,101,114,46,112,97,116,104,95,104,111,
-    111,107,46,60,108,111,99,97,108,115,62,46,112,97,116,104,
-    95,104,111,111,107,95,102,111,114,95,70,105,108,101,70,105,
-    110,100,101,114,114,3,0,0,0,41,3,114,192,0,0,0,
-    114,89,1,0,0,114,96,1,0,0,114,3,0,0,0,114,
-    95,1,0,0,114,6,0,0,0,218,9,112,97,116,104,95,
-    104,111,111,107,23,6,0,0,115,4,0,0,0,0,10,14,
-    6,122,20,70,105,108,101,70,105,110,100,101,114,46,112,97,
-    116,104,95,104,111,111,107,99,1,0,0,0,0,0,0,0,
-    0,0,0,0,1,0,0,0,3,0,0,0,67,0,0,0,
-    115,12,0,0,0,100,1,160,0,124,0,106,1,161,1,83,
-    0,41,2,78,122,16,70,105,108,101,70,105,110,100,101,114,
-    40,123,33,114,125,41,41,2,114,61,0,0,0,114,43,0,
-    0,0,114,245,0,0,0,114,3,0,0,0,114,3,0,0,
-    0,114,6,0,0,0,114,38,1,0,0,41,6,0,0,115,
-    2,0,0,0,0,1,122,19,70,105,108,101,70,105,110,100,
-    101,114,46,95,95,114,101,112,114,95,95,41,1,78,41,15,
-    114,124,0,0,0,114,123,0,0,0,114,125,0,0,0,114,
-    126,0,0,0,114,208,0,0,0,114,45,1,0,0,114,142,
-    0,0,0,114,205,0,0,0,114,136,0,0,0,114,57,1,
-    0,0,114,202,0,0,0,114,90,1,0,0,114,206,0,0,
-    0,114,97,1,0,0,114,38,1,0,0,114,3,0,0,0,
-    114,3,0,0,0,114,3,0,0,0,114,6,0,0,0,114,
-    82,1,0,0,154,5,0,0,115,22,0,0,0,8,2,4,
-    7,8,14,8,4,4,2,8,12,8,5,10,48,8,31,2,
-    1,10,17,114,82,1,0,0,99,4,0,0,0,0,0,0,
-    0,0,0,0,0,6,0,0,0,8,0,0,0,67,0,0,
-    0,115,146,0,0,0,124,0,160,0,100,1,161,1,125,4,
-    124,0,160,0,100,2,161,1,125,5,124,4,115,66,124,5,
-    114,36,124,5,106,1,125,4,110,30,124,2,124,3,107,2,
-    114,56,116,2,124,1,124,2,131,2,125,4,110,10,116,3,
-    124,1,124,2,131,2,125,4,124,5,115,84,116,4,124,1,
-    124,2,124,4,100,3,141,3,125,5,122,36,124,5,124,0,
-    100,2,60,0,124,4,124,0,100,1,60,0,124,2,124,0,
-    100,4,60,0,124,3,124,0,100,5,60,0,87,0,110,20,
-    4,0,116,5,107,10,114,140,1,0,1,0,1,0,89,0,
-    110,2,88,0,100,0,83,0,41,6,78,218,10,95,95,108,
-    111,97,100,101,114,95,95,218,8,95,95,115,112,101,99,95,
-    95,114,83,1,0,0,90,8,95,95,102,105,108,101,95,95,
-    90,10,95,95,99,97,99,104,101,100,95,95,41,6,218,3,
-    103,101,116,114,139,0,0,0,114,14,1,0,0,114,8,1,
-    0,0,114,189,0,0,0,114,71,1,0,0,41,6,90,2,
-    110,115,114,116,0,0,0,90,8,112,97,116,104,110,97,109,
-    101,90,9,99,112,97,116,104,110,97,109,101,114,139,0,0,
-    0,114,186,0,0,0,114,3,0,0,0,114,3,0,0,0,
-    114,6,0,0,0,218,14,95,102,105,120,95,117,112,95,109,
-    111,100,117,108,101,47,6,0,0,115,34,0,0,0,0,2,
-    10,1,10,1,4,1,4,1,8,1,8,1,12,2,10,1,
-    4,1,14,1,2,1,8,1,8,1,8,1,12,1,14,2,
-    114,101,1,0,0,99,0,0,0,0,0,0,0,0,0,0,
-    0,0,3,0,0,0,3,0,0,0,67,0,0,0,115,38,
-    0,0,0,116,0,116,1,160,2,161,0,102,2,125,0,116,
-    3,116,4,102,2,125,1,116,5,116,6,102,2,125,2,124,
-    0,124,1,124,2,103,3,83,0,41,1,122,95,82,101,116,
-    117,114,110,115,32,97,32,108,105,115,116,32,111,102,32,102,
-    105,108,101,45,98,97,115,101,100,32,109,111,100,117,108,101,
-    32,108,111,97,100,101,114,115,46,10,10,32,32,32,32,69,
-    97,99,104,32,105,116,101,109,32,105,115,32,97,32,116,117,
-    112,108,101,32,40,108,111,97,100,101,114,44,32,115,117,102,
-    102,105,120,101,115,41,46,10,32,32,32,32,41,7,114,251,
-    0,0,0,114,162,0,0,0,218,18,101,120,116,101,110,115,
-    105,111,110,95,115,117,102,102,105,120,101,115,114,8,1,0,
-    0,114,101,0,0,0,114,14,1,0,0,114,88,0,0,0,
-    41,3,90,10,101,120,116,101,110,115,105,111,110,115,90,6,
-    115,111,117,114,99,101,90,8,98,121,116,101,99,111,100,101,
-    114,3,0,0,0,114,3,0,0,0,114,6,0,0,0,114,
-    183,0,0,0,70,6,0,0,115,8,0,0,0,0,5,12,
-    1,8,1,8,1,114,183,0,0,0,99,1,0,0,0,0,
-    0,0,0,0,0,0,0,12,0,0,0,9,0,0,0,67,
-    0,0,0,115,178,1,0,0,124,0,97,0,116,0,106,1,
-    97,1,116,0,106,2,97,2,116,1,106,3,116,4,25,0,
-    125,1,100,1,68,0,93,48,125,2,124,2,116,1,106,3,
-    107,7,114,56,116,0,160,5,124,2,161,1,125,3,110,10,
-    116,1,106,3,124,2,25,0,125,3,116,6,124,1,124,2,
-    124,3,131,3,1,0,113,30,100,2,100,3,103,1,102,2,
-    100,4,100,5,100,3,103,2,102,2,102,2,125,4,124,4,
-    68,0,93,110,92,2,125,5,125,6,116,7,100,6,100,7,
-    132,0,124,6,68,0,131,1,131,1,115,136,74,0,130,1,
-    124,6,100,8,25,0,125,7,124,5,116,1,106,3,107,6,
-    114,170,116,1,106,3,124,5,25,0,125,8,1,0,113,226,
-    113,106,122,20,116,0,160,5,124,5,161,1,125,8,87,0,
-    1,0,113,226,87,0,113,106,4,0,116,8,107,10,114,214,
-    1,0,1,0,1,0,89,0,113,106,89,0,113,106,88,0,
-    113,106,116,8,100,9,131,1,130,1,116,6,124,1,100,10,
-    124,8,131,3,1,0,116,6,124,1,100,11,124,7,131,3,
-    1,0,116,6,124,1,100,12,100,13,160,9,124,6,161,1,
-    131,3,1,0,116,6,124,1,100,14,100,15,100,16,132,0,
-    124,6,68,0,131,1,131,3,1,0,116,0,160,5,100,17,
-    161,1,125,9,116,6,124,1,100,17,124,9,131,3,1,0,
-    116,0,160,5,100,18,161,1,125,10,116,6,124,1,100,18,
-    124,10,131,3,1,0,124,5,100,4,107,2,144,1,114,110,
-    116,0,160,5,100,19,161,1,125,11,116,6,124,1,100,20,
-    124,11,131,3,1,0,116,6,124,1,100,21,116,10,131,0,
-    131,3,1,0,116,11,160,12,116,2,160,13,161,0,161,1,
-    1,0,124,5,100,4,107,2,144,1,114,174,116,14,160,15,
-    100,22,161,1,1,0,100,23,116,11,107,6,144,1,114,174,
-    100,24,116,16,95,17,100,25,83,0,41,26,122,205,83,101,
-    116,117,112,32,116,104,101,32,112,97,116,104,45,98,97,115,
-    101,100,32,105,109,112,111,114,116,101,114,115,32,102,111,114,
-    32,105,109,112,111,114,116,108,105,98,32,98,121,32,105,109,
-    112,111,114,116,105,110,103,32,110,101,101,100,101,100,10,32,
-    32,32,32,98,117,105,108,116,45,105,110,32,109,111,100,117,
-    108,101,115,32,97,110,100,32,105,110,106,101,99,116,105,110,
-    103,32,116,104,101,109,32,105,110,116,111,32,116,104,101,32,
-    103,108,111,98,97,108,32,110,97,109,101,115,112,97,99,101,
-    46,10,10,32,32,32,32,79,116,104,101,114,32,99,111,109,
-    112,111,110,101,110,116,115,32,97,114,101,32,101,120,116,114,
-    97,99,116,101,100,32,102,114,111,109,32,116,104,101,32,99,
-    111,114,101,32,98,111,111,116,115,116,114,97,112,32,109,111,
-    100,117,108,101,46,10,10,32,32,32,32,41,4,114,63,0,
-    0,0,114,74,0,0,0,218,8,98,117,105,108,116,105,110,
-    115,114,159,0,0,0,90,5,112,111,115,105,120,250,1,47,
-    90,2,110,116,250,1,92,99,1,0,0,0,0,0,0,0,
-    0,0,0,0,2,0,0,0,3,0,0,0,115,0,0,0,
-    115,26,0,0,0,124,0,93,18,125,1,116,0,124,1,131,
-    1,100,0,107,2,86,0,1,0,113,2,100,1,83,0,41,
-    2,114,38,0,0,0,78,41,1,114,22,0,0,0,41,2,
-    114,31,0,0,0,114,94,0,0,0,114,3,0,0,0,114,
-    3,0,0,0,114,6,0,0,0,114,18,1,0,0,106,6,
-    0,0,115,4,0,0,0,4,0,2,0,122,25,95,115,101,
-    116,117,112,46,60,108,111,99,97,108,115,62,46,60,103,101,
-    110,101,120,112,114,62,114,72,0,0,0,122,30,105,109,112,
-    111,114,116,108,105,98,32,114,101,113,117,105,114,101,115,32,
-    112,111,115,105,120,32,111,114,32,110,116,114,2,0,0,0,
-    114,34,0,0,0,114,30,0,0,0,114,39,0,0,0,114,
-    57,0,0,0,99,1,0,0,0,0,0,0,0,0,0,0,
-    0,2,0,0,0,4,0,0,0,83,0,0,0,115,22,0,
-    0,0,104,0,124,0,93,14,125,1,100,0,124,1,155,0,
-    157,2,146,2,113,4,83,0,41,1,114,73,0,0,0,114,
-    3,0,0,0,41,2,114,31,0,0,0,218,1,115,114,3,
-    0,0,0,114,3,0,0,0,114,6,0,0,0,114,91,1,
-    0,0,122,6,0,0,115,4,0,0,0,6,0,2,0,122,
-    25,95,115,101,116,117,112,46,60,108,111,99,97,108,115,62,
-    46,60,115,101,116,99,111,109,112,62,90,7,95,116,104,114,
-    101,97,100,90,8,95,119,101,97,107,114,101,102,90,6,119,
-    105,110,114,101,103,114,191,0,0,0,114,7,0,0,0,122,
-    4,46,112,121,119,122,6,95,100,46,112,121,100,84,78,41,
-    18,114,133,0,0,0,114,8,0,0,0,114,162,0,0,0,
-    114,30,1,0,0,114,124,0,0,0,90,18,95,98,117,105,
-    108,116,105,110,95,102,114,111,109,95,110,97,109,101,114,128,
-    0,0,0,218,3,97,108,108,114,117,0,0,0,114,35,0,
-    0,0,114,13,0,0,0,114,20,1,0,0,114,166,0,0,
-    0,114,102,1,0,0,114,101,0,0,0,114,185,0,0,0,
-    114,190,0,0,0,114,194,0,0,0,41,12,218,17,95,98,
-    111,111,116,115,116,114,97,112,95,109,111,100,117,108,101,90,
-    11,115,101,108,102,95,109,111,100,117,108,101,90,12,98,117,
-    105,108,116,105,110,95,110,97,109,101,90,14,98,117,105,108,
-    116,105,110,95,109,111,100,117,108,101,90,10,111,115,95,100,
-    101,116,97,105,108,115,90,10,98,117,105,108,116,105,110,95,
-    111,115,114,30,0,0,0,114,34,0,0,0,90,9,111,115,
-    95,109,111,100,117,108,101,90,13,116,104,114,101,97,100,95,
-    109,111,100,117,108,101,90,14,119,101,97,107,114,101,102,95,
-    109,111,100,117,108,101,90,13,119,105,110,114,101,103,95,109,
-    111,100,117,108,101,114,3,0,0,0,114,3,0,0,0,114,
-    6,0,0,0,218,6,95,115,101,116,117,112,81,6,0,0,
-    115,78,0,0,0,0,8,4,1,6,1,6,3,10,1,8,
-    1,10,1,12,2,10,1,14,3,22,1,12,2,22,1,8,
-    1,10,1,10,1,6,2,2,1,10,1,10,1,14,1,12,
-    2,8,1,12,1,12,1,18,1,22,3,10,1,12,3,10,
-    1,12,3,10,1,10,1,12,3,14,1,14,1,10,1,10,
-    1,10,1,114,109,1,0,0,99,1,0,0,0,0,0,0,
-    0,0,0,0,0,2,0,0,0,4,0,0,0,67,0,0,
-    0,115,50,0,0,0,116,0,124,0,131,1,1,0,116,1,
-    131,0,125,1,116,2,106,3,160,4,116,5,106,6,124,1,
-    142,0,103,1,161,1,1,0,116,2,106,7,160,8,116,9,
-    161,1,1,0,100,1,83,0,41,2,122,41,73,110,115,116,
-    97,108,108,32,116,104,101,32,112,97,116,104,45,98,97,115,
-    101,100,32,105,109,112,111,114,116,32,99,111,109,112,111,110,
-    101,110,116,115,46,78,41,10,114,109,1,0,0,114,183,0,
-    0,0,114,8,0,0,0,114,50,1,0,0,114,166,0,0,
-    0,114,82,1,0,0,114,97,1,0,0,218,9,109,101,116,
-    97,95,112,97,116,104,114,185,0,0,0,114,44,1,0,0,
-    41,2,114,108,1,0,0,90,17,115,117,112,112,111,114,116,
-    101,100,95,108,111,97,100,101,114,115,114,3,0,0,0,114,
-    3,0,0,0,114,6,0,0,0,218,8,95,105,110,115,116,
-    97,108,108,146,6,0,0,115,8,0,0,0,0,2,8,1,
-    6,1,20,1,114,111,1,0,0,41,1,114,59,0,0,0,
-    41,1,78,41,3,78,78,78,41,2,114,72,0,0,0,114,
-    72,0,0,0,41,1,84,41,1,78,41,1,78,41,63,114,
-    126,0,0,0,114,12,0,0,0,90,37,95,67,65,83,69,
-    95,73,78,83,69,78,83,73,84,73,86,69,95,80,76,65,
-    84,70,79,82,77,83,95,66,89,84,69,83,95,75,69,89,
-    114,11,0,0,0,114,13,0,0,0,114,20,0,0,0,114,
-    26,0,0,0,114,28,0,0,0,114,37,0,0,0,114,46,
-    0,0,0,114,48,0,0,0,114,52,0,0,0,114,53,0,
-    0,0,114,55,0,0,0,114,58,0,0,0,114,68,0,0,
-    0,218,4,116,121,112,101,218,8,95,95,99,111,100,101,95,
-    95,114,161,0,0,0,114,18,0,0,0,114,147,0,0,0,
-    114,17,0,0,0,114,23,0,0,0,114,235,0,0,0,114,
-    91,0,0,0,114,87,0,0,0,114,101,0,0,0,114,88,
-    0,0,0,90,23,68,69,66,85,71,95,66,89,84,69,67,
-    79,68,69,95,83,85,70,70,73,88,69,83,90,27,79,80,
-    84,73,77,73,90,69,68,95,66,89,84,69,67,79,68,69,
-    95,83,85,70,70,73,88,69,83,114,97,0,0,0,114,102,
-    0,0,0,114,108,0,0,0,114,112,0,0,0,114,114,0,
-    0,0,114,135,0,0,0,114,142,0,0,0,114,151,0,0,
-    0,114,155,0,0,0,114,157,0,0,0,114,164,0,0,0,
-    114,169,0,0,0,114,170,0,0,0,114,175,0,0,0,218,
-    6,111,98,106,101,99,116,114,184,0,0,0,114,189,0,0,
-    0,114,190,0,0,0,114,207,0,0,0,114,220,0,0,0,
-    114,238,0,0,0,114,8,1,0,0,114,14,1,0,0,114,
-    20,1,0,0,114,251,0,0,0,114,21,1,0,0,114,42,
-    1,0,0,114,44,1,0,0,114,82,1,0,0,114,101,1,
-    0,0,114,183,0,0,0,114,109,1,0,0,114,111,1,0,
-    0,114,3,0,0,0,114,3,0,0,0,114,3,0,0,0,
-    114,6,0,0,0,218,8,60,109,111,100,117,108,101,62,1,
-    0,0,0,115,126,0,0,0,4,22,4,1,4,1,2,1,
-    2,255,4,4,8,17,8,5,8,5,8,6,8,6,8,12,
-    8,10,8,9,8,5,8,7,8,9,10,22,10,127,0,14,
-    16,1,12,2,4,1,4,2,6,2,6,2,8,2,16,71,
-    8,40,8,19,8,12,8,12,8,28,8,17,8,33,8,28,
-    8,24,10,13,10,10,10,11,8,14,6,3,4,1,2,255,
-    12,68,14,64,14,29,16,127,0,17,14,72,18,45,18,26,
-    4,3,18,53,14,63,14,42,14,127,0,68,14,127,0,22,
-    10,23,8,11,8,65,
+    0,0,122,30,123,112,97,116,116,101,114,110,125,45,46,42,
+    92,46,101,103,103,91,92,92,47,93,69,71,71,45,73,78,
+    70,79,114,72,1,0,0,114,73,1,0,0,41,5,114,74,
+    1,0,0,114,61,0,0,0,90,6,115,101,97,114,99,104,
+    114,84,0,0,0,114,75,1,0,0,114,76,1,0,0,114,
+    3,0,0,0,114,3,0,0,0,114,6,0,0,0,218,15,
+    95,109,97,116,99,104,101,115,95,108,101,103,97,99,121,135,
+    5,0,0,115,8,0,0,0,0,2,8,1,4,1,12,1,
+    122,26,80,97,116,104,70,105,110,100,101,114,46,95,109,97,
+    116,99,104,101,115,95,108,101,103,97,99,121,99,3,0,0,
+    0,0,0,0,0,0,0,0,0,3,0,0,0,4,0,0,
+    0,3,0,0,0,115,48,0,0,0,124,1,160,0,161,0,
+    115,12,100,1,83,0,124,2,160,1,100,2,100,3,161,2,
+    137,1,135,0,135,1,102,2,100,4,100,5,132,8,124,1,
+    160,2,161,0,68,0,131,1,83,0,41,6,78,114,3,0,
+    0,0,250,1,45,114,44,0,0,0,99,1,0,0,0,0,
+    0,0,0,0,0,0,0,2,0,0,0,5,0,0,0,51,
+    0,0,0,115,42,0,0,0,124,0,93,34,125,1,136,0,
+    160,0,136,1,124,1,161,2,115,30,136,0,160,1,136,1,
+    124,1,161,2,114,2,124,1,86,0,1,0,113,2,100,0,
+    83,0,114,109,0,0,0,41,2,114,78,1,0,0,114,79,
+    1,0,0,41,2,114,31,0,0,0,114,40,1,0,0,169,
+    2,114,192,0,0,0,114,77,1,0,0,114,3,0,0,0,
+    114,6,0,0,0,114,18,1,0,0,147,5,0,0,115,8,
+    0,0,0,4,0,2,1,12,1,12,254,122,42,80,97,116,
+    104,70,105,110,100,101,114,46,95,115,101,97,114,99,104,95,
+    112,97,116,104,46,60,108,111,99,97,108,115,62,46,60,103,
+    101,110,101,120,112,114,62,41,3,90,6,105,115,95,100,105,
+    114,114,66,0,0,0,90,7,105,116,101,114,100,105,114,41,
+    3,114,192,0,0,0,90,4,114,111,111,116,114,61,1,0,
+    0,114,3,0,0,0,114,81,1,0,0,114,6,0,0,0,
+    114,64,1,0,0,142,5,0,0,115,8,0,0,0,0,2,
+    8,1,4,1,12,1,122,23,80,97,116,104,70,105,110,100,
+    101,114,46,95,115,101,97,114,99,104,95,112,97,116,104,41,
+    1,78,41,2,78,78,41,1,78,41,1,78,41,19,114,124,
+    0,0,0,114,123,0,0,0,114,125,0,0,0,114,126,0,
+    0,0,114,206,0,0,0,114,45,1,0,0,114,51,1,0,
+    0,114,53,1,0,0,114,54,1,0,0,114,57,1,0,0,
+    114,202,0,0,0,114,205,0,0,0,114,63,1,0,0,114,
+    60,1,0,0,218,12,115,116,97,116,105,99,109,101,116,104,
+    111,100,114,67,1,0,0,114,78,1,0,0,114,79,1,0,
+    0,114,64,1,0,0,114,3,0,0,0,114,3,0,0,0,
+    114,3,0,0,0,114,6,0,0,0,114,44,1,0,0,215,
+    4,0,0,115,54,0,0,0,8,2,4,2,2,1,10,9,
+    2,1,10,12,2,1,10,21,2,1,10,14,2,1,12,31,
+    2,1,12,23,2,1,12,12,2,1,12,15,2,1,10,8,
+    2,1,10,10,2,1,10,6,2,1,10,6,2,1,114,44,
+    1,0,0,99,0,0,0,0,0,0,0,0,0,0,0,0,
+    0,0,0,0,3,0,0,0,64,0,0,0,115,90,0,0,
+    0,101,0,90,1,100,0,90,2,100,1,90,3,100,2,100,
+    3,132,0,90,4,100,4,100,5,132,0,90,5,101,6,90,
+    7,100,6,100,7,132,0,90,8,100,8,100,9,132,0,90,
+    9,100,19,100,11,100,12,132,1,90,10,100,13,100,14,132,
+    0,90,11,101,12,100,15,100,16,132,0,131,1,90,13,100,
+    17,100,18,132,0,90,14,100,10,83,0,41,20,218,10,70,
+    105,108,101,70,105,110,100,101,114,122,172,70,105,108,101,45,
+    98,97,115,101,100,32,102,105,110,100,101,114,46,10,10,32,
+    32,32,32,73,110,116,101,114,97,99,116,105,111,110,115,32,
+    119,105,116,104,32,116,104,101,32,102,105,108,101,32,115,121,
+    115,116,101,109,32,97,114,101,32,99,97,99,104,101,100,32,
+    102,111,114,32,112,101,114,102,111,114,109,97,110,99,101,44,
+    32,98,101,105,110,103,10,32,32,32,32,114,101,102,114,101,
+    115,104,101,100,32,119,104,101,110,32,116,104,101,32,100,105,
+    114,101,99,116,111,114,121,32,116,104,101,32,102,105,110,100,
+    101,114,32,105,115,32,104,97,110,100,108,105,110,103,32,104,
+    97,115,32,98,101,101,110,32,109,111,100,105,102,105,101,100,
+    46,10,10,32,32,32,32,99,2,0,0,0,0,0,0,0,
+    0,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,
+    115,84,0,0,0,103,0,125,3,124,2,68,0,93,32,92,
+    2,137,0,125,4,124,3,160,0,135,0,102,1,100,1,100,
+    2,132,8,124,4,68,0,131,1,161,1,1,0,113,8,124,
+    3,124,0,95,1,124,1,112,54,100,3,124,0,95,2,100,
+    4,124,0,95,3,116,4,131,0,124,0,95,5,116,4,131,
+    0,124,0,95,6,100,5,83,0,41,6,122,154,73,110,105,
+    116,105,97,108,105,122,101,32,119,105,116,104,32,116,104,101,
+    32,112,97,116,104,32,116,111,32,115,101,97,114,99,104,32,
+    111,110,32,97,110,100,32,97,32,118,97,114,105,97,98,108,
+    101,32,110,117,109,98,101,114,32,111,102,10,32,32,32,32,
+    32,32,32,32,50,45,116,117,112,108,101,115,32,99,111,110,
+    116,97,105,110,105,110,103,32,116,104,101,32,108,111,97,100,
+    101,114,32,97,110,100,32,116,104,101,32,102,105,108,101,32,
+    115,117,102,102,105,120,101,115,32,116,104,101,32,108,111,97,
+    100,101,114,10,32,32,32,32,32,32,32,32,114,101,99,111,
+    103,110,105,122,101,115,46,99,1,0,0,0,0,0,0,0,
+    0,0,0,0,2,0,0,0,3,0,0,0,51,0,0,0,
+    115,22,0,0,0,124,0,93,14,125,1,124,1,136,0,102,
+    2,86,0,1,0,113,2,100,0,83,0,114,109,0,0,0,
+    114,3,0,0,0,114,15,1,0,0,169,1,114,139,0,0,
+    0,114,3,0,0,0,114,6,0,0,0,114,18,1,0,0,
+    167,5,0,0,115,4,0,0,0,4,0,2,0,122,38,70,
+    105,108,101,70,105,110,100,101,114,46,95,95,105,110,105,116,
+    95,95,46,60,108,111,99,97,108,115,62,46,60,103,101,110,
+    101,120,112,114,62,114,70,0,0,0,114,104,0,0,0,78,
+    41,7,114,166,0,0,0,218,8,95,108,111,97,100,101,114,
+    115,114,43,0,0,0,218,11,95,112,97,116,104,95,109,116,
+    105,109,101,218,3,115,101,116,218,11,95,112,97,116,104,95,
+    99,97,99,104,101,218,19,95,114,101,108,97,120,101,100,95,
+    112,97,116,104,95,99,97,99,104,101,41,5,114,118,0,0,
+    0,114,43,0,0,0,218,14,108,111,97,100,101,114,95,100,
+    101,116,97,105,108,115,90,7,108,111,97,100,101,114,115,114,
+    188,0,0,0,114,3,0,0,0,114,84,1,0,0,114,6,
+    0,0,0,114,208,0,0,0,161,5,0,0,115,16,0,0,
+    0,0,4,4,1,12,1,26,1,6,2,10,1,6,1,8,
+    1,122,19,70,105,108,101,70,105,110,100,101,114,46,95,95,
+    105,110,105,116,95,95,99,1,0,0,0,0,0,0,0,0,
+    0,0,0,1,0,0,0,2,0,0,0,67,0,0,0,115,
+    10,0,0,0,100,1,124,0,95,0,100,2,83,0,41,3,
+    122,31,73,110,118,97,108,105,100,97,116,101,32,116,104,101,
+    32,100,105,114,101,99,116,111,114,121,32,109,116,105,109,101,
+    46,114,104,0,0,0,78,41,1,114,86,1,0,0,114,245,
+    0,0,0,114,3,0,0,0,114,3,0,0,0,114,6,0,
+    0,0,114,45,1,0,0,175,5,0,0,115,2,0,0,0,
+    0,2,122,28,70,105,108,101,70,105,110,100,101,114,46,105,
+    110,118,97,108,105,100,97,116,101,95,99,97,99,104,101,115,
+    99,2,0,0,0,0,0,0,0,0,0,0,0,3,0,0,
+    0,3,0,0,0,67,0,0,0,115,42,0,0,0,124,0,
+    160,0,124,1,161,1,125,2,124,2,100,1,107,8,114,26,
+    100,1,103,0,102,2,83,0,124,2,106,1,124,2,106,2,
+    112,38,103,0,102,2,83,0,41,2,122,197,84,114,121,32,
+    116,111,32,102,105,110,100,32,97,32,108,111,97,100,101,114,
+    32,102,111,114,32,116,104,101,32,115,112,101,99,105,102,105,
+    101,100,32,109,111,100,117,108,101,44,32,111,114,32,116,104,
+    101,32,110,97,109,101,115,112,97,99,101,10,32,32,32,32,
+    32,32,32,32,112,97,99,107,97,103,101,32,112,111,114,116,
+    105,111,110,115,46,32,82,101,116,117,114,110,115,32,40,108,
+    111,97,100,101,114,44,32,108,105,115,116,45,111,102,45,112,
+    111,114,116,105,111,110,115,41,46,10,10,32,32,32,32,32,
+    32,32,32,84,104,105,115,32,109,101,116,104,111,100,32,105,
+    115,32,100,101,112,114,101,99,97,116,101,100,46,32,32,85,
+    115,101,32,102,105,110,100,95,115,112,101,99,40,41,32,105,
+    110,115,116,101,97,100,46,10,10,32,32,32,32,32,32,32,
+    32,78,41,3,114,202,0,0,0,114,139,0,0,0,114,177,
+    0,0,0,41,3,114,118,0,0,0,114,138,0,0,0,114,
+    186,0,0,0,114,3,0,0,0,114,3,0,0,0,114,6,
+    0,0,0,114,136,0,0,0,181,5,0,0,115,8,0,0,
+    0,0,7,10,1,8,1,8,1,122,22,70,105,108,101,70,
+    105,110,100,101,114,46,102,105,110,100,95,108,111,97,100,101,
+    114,99,6,0,0,0,0,0,0,0,0,0,0,0,7,0,
+    0,0,6,0,0,0,67,0,0,0,115,26,0,0,0,124,
+    1,124,2,124,3,131,2,125,6,116,0,124,2,124,3,124,
+    6,124,4,100,1,141,4,83,0,41,2,78,114,176,0,0,
+    0,41,1,114,189,0,0,0,41,7,114,118,0,0,0,114,
+    187,0,0,0,114,138,0,0,0,114,43,0,0,0,90,4,
+    115,109,115,108,114,201,0,0,0,114,139,0,0,0,114,3,
+    0,0,0,114,3,0,0,0,114,6,0,0,0,114,57,1,
+    0,0,193,5,0,0,115,8,0,0,0,0,1,10,1,8,
+    1,2,255,122,20,70,105,108,101,70,105,110,100,101,114,46,
+    95,103,101,116,95,115,112,101,99,78,99,3,0,0,0,0,
+    0,0,0,0,0,0,0,14,0,0,0,8,0,0,0,67,
+    0,0,0,115,98,1,0,0,100,1,125,3,124,1,160,0,
+    100,2,161,1,100,3,25,0,125,4,122,24,116,1,124,0,
+    106,2,112,34,116,3,160,4,161,0,131,1,106,5,125,5,
+    87,0,110,24,4,0,116,6,107,10,114,66,1,0,1,0,
+    1,0,100,4,125,5,89,0,110,2,88,0,124,5,124,0,
+    106,7,107,3,114,92,124,0,160,8,161,0,1,0,124,5,
+    124,0,95,7,116,9,131,0,114,114,124,0,106,10,125,6,
+    124,4,160,11,161,0,125,7,110,10,124,0,106,12,125,6,
+    124,4,125,7,124,7,124,6,107,6,114,218,116,13,124,0,
+    106,2,124,4,131,2,125,8,124,0,106,14,68,0,93,58,
+    92,2,125,9,125,10,100,5,124,9,23,0,125,11,116,13,
+    124,8,124,11,131,2,125,12,116,15,124,12,131,1,114,150,
+    124,0,160,16,124,10,124,1,124,12,124,8,103,1,124,2,
+    161,5,2,0,1,0,83,0,113,150,116,17,124,8,131,1,
+    125,3,124,0,106,14,68,0,93,82,92,2,125,9,125,10,
+    116,13,124,0,106,2,124,4,124,9,23,0,131,2,125,12,
+    116,18,106,19,100,6,124,12,100,3,100,7,141,3,1,0,
+    124,7,124,9,23,0,124,6,107,6,114,224,116,15,124,12,
+    131,1,114,224,124,0,160,16,124,10,124,1,124,12,100,8,
+    124,2,161,5,2,0,1,0,83,0,113,224,124,3,144,1,
+    114,94,116,18,160,19,100,9,124,8,161,2,1,0,116,18,
+    160,20,124,1,100,8,161,2,125,13,124,8,103,1,124,13,
+    95,21,124,13,83,0,100,8,83,0,41,10,122,111,84,114,
+    121,32,116,111,32,102,105,110,100,32,97,32,115,112,101,99,
+    32,102,111,114,32,116,104,101,32,115,112,101,99,105,102,105,
+    101,100,32,109,111,100,117,108,101,46,10,10,32,32,32,32,
+    32,32,32,32,82,101,116,117,114,110,115,32,116,104,101,32,
+    109,97,116,99,104,105,110,103,32,115,112,101,99,44,32,111,
+    114,32,78,111,110,101,32,105,102,32,110,111,116,32,102,111,
+    117,110,100,46,10,32,32,32,32,32,32,32,32,70,114,70,
+    0,0,0,114,27,0,0,0,114,104,0,0,0,114,208,0,
+    0,0,122,9,116,114,121,105,110,103,32,123,125,41,1,90,
+    9,118,101,114,98,111,115,105,116,121,78,122,25,112,111,115,
+    115,105,98,108,101,32,110,97,109,101,115,112,97,99,101,32,
+    102,111,114,32,123,125,41,22,114,40,0,0,0,114,48,0,
+    0,0,114,43,0,0,0,114,2,0,0,0,114,54,0,0,
+    0,114,9,1,0,0,114,49,0,0,0,114,86,1,0,0,
+    218,11,95,102,105,108,108,95,99,97,99,104,101,114,7,0,
+    0,0,114,89,1,0,0,114,105,0,0,0,114,88,1,0,
+    0,114,37,0,0,0,114,85,1,0,0,114,53,0,0,0,
+    114,57,1,0,0,114,55,0,0,0,114,133,0,0,0,114,
+    148,0,0,0,114,182,0,0,0,114,177,0,0,0,41,14,
+    114,118,0,0,0,114,138,0,0,0,114,201,0,0,0,90,
+    12,105,115,95,110,97,109,101,115,112,97,99,101,90,11,116,
+    97,105,108,95,109,111,100,117,108,101,114,168,0,0,0,90,
+    5,99,97,99,104,101,90,12,99,97,99,104,101,95,109,111,
+    100,117,108,101,90,9,98,97,115,101,95,112,97,116,104,114,
+    16,1,0,0,114,187,0,0,0,90,13,105,110,105,116,95,
+    102,105,108,101,110,97,109,101,90,9,102,117,108,108,95,112,
+    97,116,104,114,186,0,0,0,114,3,0,0,0,114,3,0,
+    0,0,114,6,0,0,0,114,202,0,0,0,198,5,0,0,
+    115,74,0,0,0,0,5,4,1,14,1,2,1,24,1,14,
+    1,10,1,10,1,8,1,6,2,6,1,6,1,10,2,6,
+    1,4,2,8,1,12,1,14,1,8,1,10,1,8,1,26,
+    4,8,2,14,1,16,1,16,1,12,1,8,1,10,1,2,
+    0,2,255,10,2,6,1,12,1,12,1,8,1,4,1,122,
+    20,70,105,108,101,70,105,110,100,101,114,46,102,105,110,100,
+    95,115,112,101,99,99,1,0,0,0,0,0,0,0,0,0,
+    0,0,9,0,0,0,10,0,0,0,67,0,0,0,115,190,
+    0,0,0,124,0,106,0,125,1,122,22,116,1,160,2,124,
+    1,112,22,116,1,160,3,161,0,161,1,125,2,87,0,110,
+    30,4,0,116,4,116,5,116,6,102,3,107,10,114,58,1,
+    0,1,0,1,0,103,0,125,2,89,0,110,2,88,0,116,
+    7,106,8,160,9,100,1,161,1,115,84,116,10,124,2,131,
+    1,124,0,95,11,110,74,116,10,131,0,125,3,124,2,68,
+    0,93,56,125,4,124,4,160,12,100,2,161,1,92,3,125,
+    5,125,6,125,7,124,6,114,136,100,3,160,13,124,5,124,
+    7,160,14,161,0,161,2,125,8,110,4,124,5,125,8,124,
+    3,160,15,124,8,161,1,1,0,113,94,124,3,124,0,95,
+    11,116,7,106,8,160,9,116,16,161,1,114,186,100,4,100,
+    5,132,0,124,2,68,0,131,1,124,0,95,17,100,6,83,
+    0,41,7,122,68,70,105,108,108,32,116,104,101,32,99,97,
+    99,104,101,32,111,102,32,112,111,116,101,110,116,105,97,108,
+    32,109,111,100,117,108,101,115,32,97,110,100,32,112,97,99,
+    107,97,103,101,115,32,102,111,114,32,116,104,105,115,32,100,
+    105,114,101,99,116,111,114,121,46,114,0,0,0,0,114,70,
+    0,0,0,114,60,0,0,0,99,1,0,0,0,0,0,0,
+    0,0,0,0,0,2,0,0,0,4,0,0,0,83,0,0,
+    0,115,20,0,0,0,104,0,124,0,93,12,125,1,124,1,
+    160,0,161,0,146,2,113,4,83,0,114,3,0,0,0,41,
+    1,114,105,0,0,0,41,2,114,31,0,0,0,90,2,102,
+    110,114,3,0,0,0,114,3,0,0,0,114,6,0,0,0,
+    218,9,60,115,101,116,99,111,109,112,62,19,6,0,0,115,
+    4,0,0,0,6,0,2,0,122,41,70,105,108,101,70,105,
+    110,100,101,114,46,95,102,105,108,108,95,99,97,99,104,101,
+    46,60,108,111,99,97,108,115,62,46,60,115,101,116,99,111,
+    109,112,62,78,41,18,114,43,0,0,0,114,2,0,0,0,
+    114,6,1,0,0,114,54,0,0,0,114,2,1,0,0,218,
+    15,80,101,114,109,105,115,115,105,111,110,69,114,114,111,114,
+    218,18,78,111,116,65,68,105,114,101,99,116,111,114,121,69,
+    114,114,111,114,114,8,0,0,0,114,9,0,0,0,114,10,
+    0,0,0,114,87,1,0,0,114,88,1,0,0,114,100,0,
+    0,0,114,61,0,0,0,114,105,0,0,0,218,3,97,100,
+    100,114,11,0,0,0,114,89,1,0,0,41,9,114,118,0,
+    0,0,114,43,0,0,0,114,7,1,0,0,90,21,108,111,
+    119,101,114,95,115,117,102,102,105,120,95,99,111,110,116,101,
+    110,116,115,114,40,1,0,0,114,116,0,0,0,114,28,1,
+    0,0,114,16,1,0,0,90,8,110,101,119,95,110,97,109,
+    101,114,3,0,0,0,114,3,0,0,0,114,6,0,0,0,
+    114,91,1,0,0,246,5,0,0,115,34,0,0,0,0,2,
+    6,1,2,1,22,1,20,3,10,3,12,1,12,7,6,1,
+    8,1,16,1,4,1,18,2,4,1,12,1,6,1,12,1,
+    122,22,70,105,108,101,70,105,110,100,101,114,46,95,102,105,
+    108,108,95,99,97,99,104,101,99,1,0,0,0,0,0,0,
+    0,0,0,0,0,3,0,0,0,3,0,0,0,7,0,0,
+    0,115,18,0,0,0,135,0,135,1,102,2,100,1,100,2,
+    132,8,125,2,124,2,83,0,41,3,97,20,1,0,0,65,
+    32,99,108,97,115,115,32,109,101,116,104,111,100,32,119,104,
+    105,99,104,32,114,101,116,117,114,110,115,32,97,32,99,108,
+    111,115,117,114,101,32,116,111,32,117,115,101,32,111,110,32,
+    115,121,115,46,112,97,116,104,95,104,111,111,107,10,32,32,
+    32,32,32,32,32,32,119,104,105,99,104,32,119,105,108,108,
+    32,114,101,116,117,114,110,32,97,110,32,105,110,115,116,97,
+    110,99,101,32,117,115,105,110,103,32,116,104,101,32,115,112,
+    101,99,105,102,105,101,100,32,108,111,97,100,101,114,115,32,
+    97,110,100,32,116,104,101,32,112,97,116,104,10,32,32,32,
+    32,32,32,32,32,99,97,108,108,101,100,32,111,110,32,116,
+    104,101,32,99,108,111,115,117,114,101,46,10,10,32,32,32,
+    32,32,32,32,32,73,102,32,116,104,101,32,112,97,116,104,
+    32,99,97,108,108,101,100,32,111,110,32,116,104,101,32,99,
+    108,111,115,117,114,101,32,105,115,32,110,111,116,32,97,32,
+    100,105,114,101,99,116,111,114,121,44,32,73,109,112,111,114,
+    116,69,114,114,111,114,32,105,115,10,32,32,32,32,32,32,
+    32,32,114,97,105,115,101,100,46,10,10,32,32,32,32,32,
+    32,32,32,99,1,0,0,0,0,0,0,0,0,0,0,0,
+    1,0,0,0,4,0,0,0,19,0,0,0,115,34,0,0,
+    0,116,0,124,0,131,1,115,20,116,1,100,1,124,0,100,
+    2,141,2,130,1,136,0,124,0,102,1,136,1,158,2,142,
+    0,83,0,41,3,122,45,80,97,116,104,32,104,111,111,107,
+    32,102,111,114,32,105,109,112,111,114,116,108,105,98,46,109,
+    97,99,104,105,110,101,114,121,46,70,105,108,101,70,105,110,
+    100,101,114,46,122,30,111,110,108,121,32,100,105,114,101,99,
+    116,111,114,105,101,115,32,97,114,101,32,115,117,112,112,111,
+    114,116,101,100,114,47,0,0,0,41,2,114,55,0,0,0,
+    114,117,0,0,0,114,47,0,0,0,169,2,114,192,0,0,
+    0,114,90,1,0,0,114,3,0,0,0,114,6,0,0,0,
+    218,24,112,97,116,104,95,104,111,111,107,95,102,111,114,95,
+    70,105,108,101,70,105,110,100,101,114,31,6,0,0,115,6,
+    0,0,0,0,2,8,1,12,1,122,54,70,105,108,101,70,
+    105,110,100,101,114,46,112,97,116,104,95,104,111,111,107,46,
+    60,108,111,99,97,108,115,62,46,112,97,116,104,95,104,111,
+    111,107,95,102,111,114,95,70,105,108,101,70,105,110,100,101,
+    114,114,3,0,0,0,41,3,114,192,0,0,0,114,90,1,
+    0,0,114,97,1,0,0,114,3,0,0,0,114,96,1,0,
+    0,114,6,0,0,0,218,9,112,97,116,104,95,104,111,111,
+    107,21,6,0,0,115,4,0,0,0,0,10,14,6,122,20,
+    70,105,108,101,70,105,110,100,101,114,46,112,97,116,104,95,
+    104,111,111,107,99,1,0,0,0,0,0,0,0,0,0,0,
+    0,1,0,0,0,3,0,0,0,67,0,0,0,115,12,0,
+    0,0,100,1,160,0,124,0,106,1,161,1,83,0,41,2,
+    78,122,16,70,105,108,101,70,105,110,100,101,114,40,123,33,
+    114,125,41,41,2,114,61,0,0,0,114,43,0,0,0,114,
+    245,0,0,0,114,3,0,0,0,114,3,0,0,0,114,6,
+    0,0,0,114,38,1,0,0,39,6,0,0,115,2,0,0,
+    0,0,1,122,19,70,105,108,101,70,105,110,100,101,114,46,
+    95,95,114,101,112,114,95,95,41,1,78,41,15,114,124,0,
+    0,0,114,123,0,0,0,114,125,0,0,0,114,126,0,0,
+    0,114,208,0,0,0,114,45,1,0,0,114,142,0,0,0,
+    114,205,0,0,0,114,136,0,0,0,114,57,1,0,0,114,
+    202,0,0,0,114,91,1,0,0,114,206,0,0,0,114,98,
+    1,0,0,114,38,1,0,0,114,3,0,0,0,114,3,0,
+    0,0,114,3,0,0,0,114,6,0,0,0,114,83,1,0,
+    0,152,5,0,0,115,22,0,0,0,8,2,4,7,8,14,
+    8,4,4,2,8,12,8,5,10,48,8,31,2,1,10,17,
+    114,83,1,0,0,99,4,0,0,0,0,0,0,0,0,0,
+    0,0,6,0,0,0,8,0,0,0,67,0,0,0,115,146,
+    0,0,0,124,0,160,0,100,1,161,1,125,4,124,0,160,
+    0,100,2,161,1,125,5,124,4,115,66,124,5,114,36,124,
+    5,106,1,125,4,110,30,124,2,124,3,107,2,114,56,116,
+    2,124,1,124,2,131,2,125,4,110,10,116,3,124,1,124,
+    2,131,2,125,4,124,5,115,84,116,4,124,1,124,2,124,
+    4,100,3,141,3,125,5,122,36,124,5,124,0,100,2,60,
+    0,124,4,124,0,100,1,60,0,124,2,124,0,100,4,60,
+    0,124,3,124,0,100,5,60,0,87,0,110,20,4,0,116,
+    5,107,10,114,140,1,0,1,0,1,0,89,0,110,2,88,
+    0,100,0,83,0,41,6,78,218,10,95,95,108,111,97,100,
+    101,114,95,95,218,8,95,95,115,112,101,99,95,95,114,84,
+    1,0,0,90,8,95,95,102,105,108,101,95,95,90,10,95,
+    95,99,97,99,104,101,100,95,95,41,6,218,3,103,101,116,
+    114,139,0,0,0,114,14,1,0,0,114,8,1,0,0,114,
+    189,0,0,0,114,71,1,0,0,41,6,90,2,110,115,114,
+    116,0,0,0,90,8,112,97,116,104,110,97,109,101,90,9,
+    99,112,97,116,104,110,97,109,101,114,139,0,0,0,114,186,
+    0,0,0,114,3,0,0,0,114,3,0,0,0,114,6,0,
+    0,0,218,14,95,102,105,120,95,117,112,95,109,111,100,117,
+    108,101,45,6,0,0,115,34,0,0,0,0,2,10,1,10,
+    1,4,1,4,1,8,1,8,1,12,2,10,1,4,1,14,
+    1,2,1,8,1,8,1,8,1,12,1,14,2,114,102,1,
+    0,0,99,0,0,0,0,0,0,0,0,0,0,0,0,3,
+    0,0,0,3,0,0,0,67,0,0,0,115,38,0,0,0,
+    116,0,116,1,160,2,161,0,102,2,125,0,116,3,116,4,
+    102,2,125,1,116,5,116,6,102,2,125,2,124,0,124,1,
+    124,2,103,3,83,0,41,1,122,95,82,101,116,117,114,110,
+    115,32,97,32,108,105,115,116,32,111,102,32,102,105,108,101,
+    45,98,97,115,101,100,32,109,111,100,117,108,101,32,108,111,
+    97,100,101,114,115,46,10,10,32,32,32,32,69,97,99,104,
+    32,105,116,101,109,32,105,115,32,97,32,116,117,112,108,101,
+    32,40,108,111,97,100,101,114,44,32,115,117,102,102,105,120,
+    101,115,41,46,10,32,32,32,32,41,7,114,251,0,0,0,
+    114,162,0,0,0,218,18,101,120,116,101,110,115,105,111,110,
+    95,115,117,102,102,105,120,101,115,114,8,1,0,0,114,101,
+    0,0,0,114,14,1,0,0,114,88,0,0,0,41,3,90,
+    10,101,120,116,101,110,115,105,111,110,115,90,6,115,111,117,
+    114,99,101,90,8,98,121,116,101,99,111,100,101,114,3,0,
+    0,0,114,3,0,0,0,114,6,0,0,0,114,183,0,0,
+    0,68,6,0,0,115,8,0,0,0,0,5,12,1,8,1,
+    8,1,114,183,0,0,0,99,1,0,0,0,0,0,0,0,
+    0,0,0,0,12,0,0,0,9,0,0,0,67,0,0,0,
+    115,178,1,0,0,124,0,97,0,116,0,106,1,97,1,116,
+    0,106,2,97,2,116,1,106,3,116,4,25,0,125,1,100,
+    1,68,0,93,48,125,2,124,2,116,1,106,3,107,7,114,
+    56,116,0,160,5,124,2,161,1,125,3,110,10,116,1,106,
+    3,124,2,25,0,125,3,116,6,124,1,124,2,124,3,131,
+    3,1,0,113,30,100,2,100,3,103,1,102,2,100,4,100,
+    5,100,3,103,2,102,2,102,2,125,4,124,4,68,0,93,
+    110,92,2,125,5,125,6,116,7,100,6,100,7,132,0,124,
+    6,68,0,131,1,131,1,115,136,74,0,130,1,124,6,100,
+    8,25,0,125,7,124,5,116,1,106,3,107,6,114,170,116,
+    1,106,3,124,5,25,0,125,8,1,0,113,226,113,106,122,
+    20,116,0,160,5,124,5,161,1,125,8,87,0,1,0,113,
+    226,87,0,113,106,4,0,116,8,107,10,114,214,1,0,1,
+    0,1,0,89,0,113,106,89,0,113,106,88,0,113,106,116,
+    8,100,9,131,1,130,1,116,6,124,1,100,10,124,8,131,
+    3,1,0,116,6,124,1,100,11,124,7,131,3,1,0,116,
+    6,124,1,100,12,100,13,160,9,124,6,161,1,131,3,1,
+    0,116,6,124,1,100,14,100,15,100,16,132,0,124,6,68,
+    0,131,1,131,3,1,0,116,0,160,5,100,17,161,1,125,
+    9,116,6,124,1,100,17,124,9,131,3,1,0,116,0,160,
+    5,100,18,161,1,125,10,116,6,124,1,100,18,124,10,131,
+    3,1,0,124,5,100,4,107,2,144,1,114,110,116,0,160,
+    5,100,19,161,1,125,11,116,6,124,1,100,20,124,11,131,
+    3,1,0,116,6,124,1,100,21,116,10,131,0,131,3,1,
+    0,116,11,160,12,116,2,160,13,161,0,161,1,1,0,124,
+    5,100,4,107,2,144,1,114,174,116,14,160,15,100,22,161,
+    1,1,0,100,23,116,11,107,6,144,1,114,174,100,24,116,
+    16,95,17,100,25,83,0,41,26,122,205,83,101,116,117,112,
+    32,116,104,101,32,112,97,116,104,45,98,97,115,101,100,32,
+    105,109,112,111,114,116,101,114,115,32,102,111,114,32,105,109,
+    112,111,114,116,108,105,98,32,98,121,32,105,109,112,111,114,
+    116,105,110,103,32,110,101,101,100,101,100,10,32,32,32,32,
+    98,117,105,108,116,45,105,110,32,109,111,100,117,108,101,115,
+    32,97,110,100,32,105,110,106,101,99,116,105,110,103,32,116,
+    104,101,109,32,105,110,116,111,32,116,104,101,32,103,108,111,
+    98,97,108,32,110,97,109,101,115,112,97,99,101,46,10,10,
+    32,32,32,32,79,116,104,101,114,32,99,111,109,112,111,110,
+    101,110,116,115,32,97,114,101,32,101,120,116,114,97,99,116,
+    101,100,32,102,114,111,109,32,116,104,101,32,99,111,114,101,
+    32,98,111,111,116,115,116,114,97,112,32,109,111,100,117,108,
+    101,46,10,10,32,32,32,32,41,4,114,63,0,0,0,114,
+    74,0,0,0,218,8,98,117,105,108,116,105,110,115,114,159,
+    0,0,0,90,5,112,111,115,105,120,250,1,47,90,2,110,
+    116,250,1,92,99,1,0,0,0,0,0,0,0,0,0,0,
+    0,2,0,0,0,3,0,0,0,115,0,0,0,115,26,0,
+    0,0,124,0,93,18,125,1,116,0,124,1,131,1,100,0,
+    107,2,86,0,1,0,113,2,100,1,83,0,41,2,114,38,
+    0,0,0,78,41,1,114,22,0,0,0,41,2,114,31,0,
+    0,0,114,94,0,0,0,114,3,0,0,0,114,3,0,0,
+    0,114,6,0,0,0,114,18,1,0,0,104,6,0,0,115,
+    4,0,0,0,4,0,2,0,122,25,95,115,101,116,117,112,
+    46,60,108,111,99,97,108,115,62,46,60,103,101,110,101,120,
+    112,114,62,114,72,0,0,0,122,30,105,109,112,111,114,116,
+    108,105,98,32,114,101,113,117,105,114,101,115,32,112,111,115,
+    105,120,32,111,114,32,110,116,114,2,0,0,0,114,34,0,
+    0,0,114,30,0,0,0,114,39,0,0,0,114,57,0,0,
+    0,99,1,0,0,0,0,0,0,0,0,0,0,0,2,0,
+    0,0,4,0,0,0,83,0,0,0,115,22,0,0,0,104,
+    0,124,0,93,14,125,1,100,0,124,1,155,0,157,2,146,
+    2,113,4,83,0,41,1,114,73,0,0,0,114,3,0,0,
+    0,41,2,114,31,0,0,0,218,1,115,114,3,0,0,0,
+    114,3,0,0,0,114,6,0,0,0,114,92,1,0,0,120,
+    6,0,0,115,4,0,0,0,6,0,2,0,122,25,95,115,
+    101,116,117,112,46,60,108,111,99,97,108,115,62,46,60,115,
+    101,116,99,111,109,112,62,90,7,95,116,104,114,101,97,100,
+    90,8,95,119,101,97,107,114,101,102,90,6,119,105,110,114,
+    101,103,114,191,0,0,0,114,7,0,0,0,122,4,46,112,
+    121,119,122,6,95,100,46,112,121,100,84,78,41,18,114,133,
+    0,0,0,114,8,0,0,0,114,162,0,0,0,114,30,1,
+    0,0,114,124,0,0,0,90,18,95,98,117,105,108,116,105,
+    110,95,102,114,111,109,95,110,97,109,101,114,128,0,0,0,
+    218,3,97,108,108,114,117,0,0,0,114,35,0,0,0,114,
+    13,0,0,0,114,20,1,0,0,114,166,0,0,0,114,103,
+    1,0,0,114,101,0,0,0,114,185,0,0,0,114,190,0,
+    0,0,114,194,0,0,0,41,12,218,17,95,98,111,111,116,
+    115,116,114,97,112,95,109,111,100,117,108,101,90,11,115,101,
+    108,102,95,109,111,100,117,108,101,90,12,98,117,105,108,116,
+    105,110,95,110,97,109,101,90,14,98,117,105,108,116,105,110,
+    95,109,111,100,117,108,101,90,10,111,115,95,100,101,116,97,
+    105,108,115,90,10,98,117,105,108,116,105,110,95,111,115,114,
+    30,0,0,0,114,34,0,0,0,90,9,111,115,95,109,111,
+    100,117,108,101,90,13,116,104,114,101,97,100,95,109,111,100,
+    117,108,101,90,14,119,101,97,107,114,101,102,95,109,111,100,
+    117,108,101,90,13,119,105,110,114,101,103,95,109,111,100,117,
+    108,101,114,3,0,0,0,114,3,0,0,0,114,6,0,0,
+    0,218,6,95,115,101,116,117,112,79,6,0,0,115,78,0,
+    0,0,0,8,4,1,6,1,6,3,10,1,8,1,10,1,
+    12,2,10,1,14,3,22,1,12,2,22,1,8,1,10,1,
+    10,1,6,2,2,1,10,1,10,1,14,1,12,2,8,1,
+    12,1,12,1,18,1,22,3,10,1,12,3,10,1,12,3,
+    10,1,10,1,12,3,14,1,14,1,10,1,10,1,10,1,
+    114,110,1,0,0,99,1,0,0,0,0,0,0,0,0,0,
+    0,0,2,0,0,0,4,0,0,0,67,0,0,0,115,50,
+    0,0,0,116,0,124,0,131,1,1,0,116,1,131,0,125,
+    1,116,2,106,3,160,4,116,5,106,6,124,1,142,0,103,
+    1,161,1,1,0,116,2,106,7,160,8,116,9,161,1,1,
+    0,100,1,83,0,41,2,122,41,73,110,115,116,97,108,108,
+    32,116,104,101,32,112,97,116,104,45,98,97,115,101,100,32,
+    105,109,112,111,114,116,32,99,111,109,112,111,110,101,110,116,
+    115,46,78,41,10,114,110,1,0,0,114,183,0,0,0,114,
+    8,0,0,0,114,50,1,0,0,114,166,0,0,0,114,83,
+    1,0,0,114,98,1,0,0,218,9,109,101,116,97,95,112,
+    97,116,104,114,185,0,0,0,114,44,1,0,0,41,2,114,
+    109,1,0,0,90,17,115,117,112,112,111,114,116,101,100,95,
+    108,111,97,100,101,114,115,114,3,0,0,0,114,3,0,0,
+    0,114,6,0,0,0,218,8,95,105,110,115,116,97,108,108,
+    144,6,0,0,115,8,0,0,0,0,2,8,1,6,1,20,
+    1,114,112,1,0,0,41,1,114,59,0,0,0,41,1,78,
+    41,3,78,78,78,41,2,114,72,0,0,0,114,72,0,0,
+    0,41,1,84,41,1,78,41,1,78,41,63,114,126,0,0,
+    0,114,12,0,0,0,90,37,95,67,65,83,69,95,73,78,
+    83,69,78,83,73,84,73,86,69,95,80,76,65,84,70,79,
+    82,77,83,95,66,89,84,69,83,95,75,69,89,114,11,0,
+    0,0,114,13,0,0,0,114,20,0,0,0,114,26,0,0,
+    0,114,28,0,0,0,114,37,0,0,0,114,46,0,0,0,
+    114,48,0,0,0,114,52,0,0,0,114,53,0,0,0,114,
+    55,0,0,0,114,58,0,0,0,114,68,0,0,0,218,4,
+    116,121,112,101,218,8,95,95,99,111,100,101,95,95,114,161,
+    0,0,0,114,18,0,0,0,114,147,0,0,0,114,17,0,
+    0,0,114,23,0,0,0,114,235,0,0,0,114,91,0,0,
+    0,114,87,0,0,0,114,101,0,0,0,114,88,0,0,0,
+    90,23,68,69,66,85,71,95,66,89,84,69,67,79,68,69,
+    95,83,85,70,70,73,88,69,83,90,27,79,80,84,73,77,
+    73,90,69,68,95,66,89,84,69,67,79,68,69,95,83,85,
+    70,70,73,88,69,83,114,97,0,0,0,114,102,0,0,0,
+    114,108,0,0,0,114,112,0,0,0,114,114,0,0,0,114,
+    135,0,0,0,114,142,0,0,0,114,151,0,0,0,114,155,
+    0,0,0,114,157,0,0,0,114,164,0,0,0,114,169,0,
+    0,0,114,170,0,0,0,114,175,0,0,0,218,6,111,98,
+    106,101,99,116,114,184,0,0,0,114,189,0,0,0,114,190,
+    0,0,0,114,207,0,0,0,114,220,0,0,0,114,238,0,
+    0,0,114,8,1,0,0,114,14,1,0,0,114,20,1,0,
+    0,114,251,0,0,0,114,21,1,0,0,114,42,1,0,0,
+    114,44,1,0,0,114,83,1,0,0,114,102,1,0,0,114,
+    183,0,0,0,114,110,1,0,0,114,112,1,0,0,114,3,
+    0,0,0,114,3,0,0,0,114,3,0,0,0,114,6,0,
+    0,0,218,8,60,109,111,100,117,108,101,62,1,0,0,0,
+    115,126,0,0,0,4,22,4,1,4,1,2,1,2,255,4,
+    4,8,17,8,5,8,5,8,6,8,6,8,12,8,10,8,
+    9,8,5,8,7,8,9,10,22,10,127,0,14,16,1,12,
+    2,4,1,4,2,6,2,6,2,8,2,16,71,8,40,8,
+    19,8,12,8,12,8,28,8,17,8,33,8,28,8,24,10,
+    13,10,10,10,11,8,14,6,3,4,1,2,255,12,68,14,
+    64,14,29,16,127,0,17,14,72,18,45,18,26,4,3,18,
+    53,14,63,14,42,14,127,0,66,14,127,0,22,10,23,8,
+    11,8,65,
 };



More information about the Python-checkins mailing list
diff --git a/Lib/importlib/_bootstrap_external.py b/Lib/importlib/_bootstrap_external.py
index 671b043c73d5..ec4bbec41e5a 100644
--- a/Lib/importlib/_bootstrap_external.py
+++ b/Lib/importlib/_bootstrap_external.py
@@ -1370,21 +1370,19 @@ def find_module(cls, fullname, path=None):
         return spec.loader
 
     @classmethod
-    def find_distributions(cls, name=None, path=None):
+    def find_distributions(self, context=None):
         """
         Find distributions.
 
         Return an iterable of all Distribution instances capable of
-        loading the metadata for packages matching the ``name``
-        (or all names if not supplied) along the paths in the list
-        of directories ``path`` (defaults to sys.path).
+        loading the metadata for packages matching ``context.name``
+        (or all names if ``None`` indicated) along the paths in the list
+        of directories ``context.path``.
         """
-        import re
-        from importlib.metadata import PathDistribution
-        if path is None:
-            path = sys.path
-        pattern = '.*' if name is None else re.escape(name)
-        found = cls._search_paths(pattern, path)
+        from importlib.metadata import PathDistribution, DistributionFinder
+        if context is None:
+            context = DistributionFinder.Context()
+        found = self._search_paths(context.pattern, context.path)
         return map(PathDistribution, found)
 
     @classmethod